pub enum AuthMode {
Apikey,
Chatgpt,
ChatgptAuthTokens,
Headers,
AgentIdentity,
PersonalAccessToken,
BedrockApiKey,
}Expand description
Authentication mode for OpenAI-backed providers.
JSON schema
{
"description": "Authentication mode for OpenAI-backed providers.",
"oneOf": [
{
"description": "OpenAI API key provided by the caller and stored by Codex.",
"type": "string",
"enum": [
"apikey"
]
},
{
"description": "ChatGPT OAuth managed by Codex (tokens persisted and refreshed by Codex).",
"type": "string",
"enum": [
"chatgpt"
]
},
{
"description": "[UNSTABLE] FOR OPENAI INTERNAL USE ONLY - DO NOT USE.\n\nChatGPT auth tokens are supplied by an external host app and are only stored in memory. Token refresh must be handled by the external host app.",
"type": "string",
"enum": [
"chatgptAuthTokens"
]
},
{
"description": "Backend auth supplied as request headers.",
"type": "string",
"enum": [
"headers"
]
},
{
"description": "Programmatic Codex auth backed by a registered Agent Identity.",
"type": "string",
"enum": [
"agentIdentity"
]
},
{
"description": "Programmatic Codex auth backed by a personal access token.",
"type": "string",
"enum": [
"personalAccessToken"
]
},
{
"description": "Amazon Bedrock bearer token managed by Codex.",
"type": "string",
"enum": [
"bedrockApiKey"
]
}
]
}Variants
Apikey
OpenAI API key provided by the caller and stored by Codex.
Chatgpt
ChatGPT OAuth managed by Codex (tokens persisted and refreshed by Codex).
ChatgptAuthTokens
[UNSTABLE] FOR OPENAI INTERNAL USE ONLY - DO NOT USE.
ChatGPT auth tokens are supplied by an external host app and are only stored in memory. Token refresh must be handled by the external host app.
Headers
Backend auth supplied as request headers.
AgentIdentity
Programmatic Codex auth backed by a registered Agent Identity.
PersonalAccessToken
Programmatic Codex auth backed by a personal access token.
BedrockApiKey
Amazon Bedrock bearer token managed by Codex.