CodexErrorInfo

Enum CodexErrorInfo 

pub enum CodexErrorInfo {
Show 16 variants ContextWindowExceeded, SessionBudgetExceeded, UsageLimitExceeded, ServerOverloaded, CyberPolicy, InternalServerError, Unauthorized, BadRequest, ThreadRollbackFailed, SandboxError, Other, HttpConnectionFailed { http_status_code: Option<u16>, }, ResponseStreamConnectionFailed { http_status_code: Option<u16>, }, ResponseStreamDisconnected { http_status_code: Option<u16>, }, ResponseTooManyFailedAttempts { http_status_code: Option<u16>, }, ActiveTurnNotSteerable { turn_kind: NonSteerableTurnKind, },
}
This translation layer make sure that we expose codex error code in camel case.

When an upstream HTTP status is available (for example, from the Responses API or a provider), it is forwarded in httpStatusCode on the relevant codexErrorInfo variant.

JSON schema
{
 "description": "This translation layer make sure that we expose codex error code in camel case.\n\nWhen an upstream HTTP status is available (for example, from the Responses API or a provider), it is forwarded in `httpStatusCode` on the relevant `codexErrorInfo` variant.",
 "oneOf": [
   {
     "type": "string",
     "enum": [
       "contextWindowExceeded",
       "sessionBudgetExceeded",
       "usageLimitExceeded",
       "serverOverloaded",
       "cyberPolicy",
       "internalServerError",
       "unauthorized",
       "badRequest",
       "threadRollbackFailed",
       "sandboxError",
       "other"
     ]
   },
   {
     "title": "HttpConnectionFailedCodexErrorInfo",
     "type": "object",
     "required": [
       "httpConnectionFailed"
     ],
     "properties": {
       "httpConnectionFailed": {
         "type": "object",
         "properties": {
           "httpStatusCode": {
             "type": [
               "integer",
               "null"
             ],
             "format": "uint16",
             "minimum": 0.0
           }
         }
       }
     },
     "additionalProperties": false
   },
   {
     "title": "ResponseStreamConnectionFailedCodexErrorInfo",
     "description": "Failed to connect to the response SSE stream.",
     "type": "object",
     "required": [
       "responseStreamConnectionFailed"
     ],
     "properties": {
       "responseStreamConnectionFailed": {
         "type": "object",
         "properties": {
           "httpStatusCode": {
             "type": [
               "integer",
               "null"
             ],
             "format": "uint16",
             "minimum": 0.0
           }
         }
       }
     },
     "additionalProperties": false
   },
   {
     "title": "ResponseStreamDisconnectedCodexErrorInfo",
     "description": "The response SSE stream disconnected in the middle of a turn before completion.",
     "type": "object",
     "required": [
       "responseStreamDisconnected"
     ],
     "properties": {
       "responseStreamDisconnected": {
         "type": "object",
         "properties": {
           "httpStatusCode": {
             "type": [
               "integer",
               "null"
             ],
             "format": "uint16",
             "minimum": 0.0
           }
         }
       }
     },
     "additionalProperties": false
   },
   {
     "title": "ResponseTooManyFailedAttemptsCodexErrorInfo",
     "description": "Reached the retry limit for responses.",
     "type": "object",
     "required": [
       "responseTooManyFailedAttempts"
     ],
     "properties": {
       "responseTooManyFailedAttempts": {
         "type": "object",
         "properties": {
           "httpStatusCode": {
             "type": [
               "integer",
               "null"
             ],
             "format": "uint16",
             "minimum": 0.0
           }
         }
       }
     },
     "additionalProperties": false
   },
   {
     "title": "ActiveTurnNotSteerableCodexErrorInfo",
     "description": "Returned when `turn/start` or `turn/steer` is submitted while the current active turn cannot accept same-turn steering, for example `/review` or manual `/compact`.",
     "type": "object",
     "required": [
       "activeTurnNotSteerable"
     ],
     "properties": {
       "activeTurnNotSteerable": {
         "type": "object",
         "required": [
           "turnKind"
         ],
         "properties": {
           "turnKind": {
             "$ref": "#/definitions/NonSteerableTurnKind"
           }
         }
       }
     },
     "additionalProperties": false
   }
 ]
}

Variants



ContextWindowExceeded



SessionBudgetExceeded



UsageLimitExceeded



ServerOverloaded



CyberPolicy



InternalServerError



Unauthorized



BadRequest



ThreadRollbackFailed



SandboxError



Other



HttpConnectionFailed

Fields

http_status_code: Option<u16>


ResponseStreamConnectionFailed

Failed to connect to the response SSE stream.

Fields

http_status_code: Option<u16>


ResponseStreamDisconnected

The response SSE stream disconnected in the middle of a turn before completion.

Fields

http_status_code: Option<u16>


ResponseTooManyFailedAttempts

Reached the retry limit for responses.

Fields

http_status_code: Option<u16>


ActiveTurnNotSteerable

Returned when turn/start or turn/steer is submitted while the current active turn cannot accept same-turn steering, for example /review or manual /compact.

Fields