pub enum ConsumeAccountRateLimitResetCreditOutcome {
Reset,
NothingToReset,
NoCredit,
AlreadyRedeemed,
}Expand description
ConsumeAccountRateLimitResetCreditOutcome
JSON schema
{
"oneOf": [
{
"description": "A reset credit was consumed and the eligible rate-limit windows were reset.",
"type": "string",
"enum": [
"reset"
]
},
{
"description": "No current rate-limit window is eligible for a reset.",
"type": "string",
"enum": [
"nothingToReset"
]
},
{
"description": "The account has no earned reset credits available.",
"type": "string",
"enum": [
"noCredit"
]
},
{
"description": "The same idempotency key already completed a reset successfully.",
"type": "string",
"enum": [
"alreadyRedeemed"
]
}
]
}Variants
Reset
A reset credit was consumed and the eligible rate-limit windows were reset.
NothingToReset
No current rate-limit window is eligible for a reset.
NoCredit
The account has no earned reset credits available.
AlreadyRedeemed
The same idempotency key already completed a reset successfully.