pub enum ExperimentalFeatureStage {
Beta,
UnderDevelopment,
Stable,
Deprecated,
Removed,
}Expand description
ExperimentalFeatureStage
JSON schema
{
"oneOf": [
{
"description": "Feature is available for user testing and feedback.",
"type": "string",
"enum": [
"beta"
]
},
{
"description": "Feature is still being built and not ready for broad use.",
"type": "string",
"enum": [
"underDevelopment"
]
},
{
"description": "Feature is production-ready.",
"type": "string",
"enum": [
"stable"
]
},
{
"description": "Feature is deprecated and should be avoided.",
"type": "string",
"enum": [
"deprecated"
]
},
{
"description": "Feature flag is retained only for backwards compatibility.",
"type": "string",
"enum": [
"removed"
]
}
]
}Variants
Beta
Feature is available for user testing and feedback.
UnderDevelopment
Feature is still being built and not ready for broad use.
Stable
Feature is production-ready.
Deprecated
Feature is deprecated and should be avoided.
Removed
Feature flag is retained only for backwards compatibility.