pub enum FileChangeApprovalDecision {
Accept,
AcceptForSession,
Decline,
Cancel,
}Expand description
FileChangeApprovalDecision
JSON schema
{
"oneOf": [
{
"description": "User approved the file changes.",
"type": "string",
"enum": [
"accept"
]
},
{
"description": "User approved the file changes and future changes to the same files should run without prompting.",
"type": "string",
"enum": [
"acceptForSession"
]
},
{
"description": "User denied the file changes. The agent will continue the turn.",
"type": "string",
"enum": [
"decline"
]
},
{
"description": "User denied the file changes. The turn will also be immediately interrupted.",
"type": "string",
"enum": [
"cancel"
]
}
]
}Variants
Accept
User approved the file changes.
AcceptForSession
User approved the file changes and future changes to the same files should run without prompting.
Decline
User denied the file changes. The agent will continue the turn.
Cancel
User denied the file changes. The turn will also be immediately interrupted.