pub enum FunctionCallOutputContentItem {
InputText {
text: String,
},
InputImage {
detail: Option<ImageDetail>,
image_url: String,
},
EncryptedContent {
encrypted_content: String,
},
}Expand description
Responses API compatible content items that can be returned by a tool call. This is a subset of ContentItem with the types we support as function call outputs.
JSON schema
{
"description": "Responses API compatible content items that can be returned by a tool call. This is a subset of ContentItem with the types we support as function call outputs.",
"oneOf": [
{
"title": "InputTextFunctionCallOutputContentItem",
"type": "object",
"required": [
"text",
"type"
],
"properties": {
"text": {
"type": "string"
},
"type": {
"title": "InputTextFunctionCallOutputContentItemType",
"type": "string",
"enum": [
"input_text"
]
}
}
},
{
"title": "InputImageFunctionCallOutputContentItem",
"type": "object",
"required": [
"image_url",
"type"
],
"properties": {
"detail": {
"anyOf": [
{
"$ref": "#/definitions/ImageDetail"
},
{
"type": "null"
}
]
},
"image_url": {
"type": "string"
},
"type": {
"title": "InputImageFunctionCallOutputContentItemType",
"type": "string",
"enum": [
"input_image"
]
}
}
},
{
"title": "EncryptedContentFunctionCallOutputContentItem",
"type": "object",
"required": [
"encrypted_content",
"type"
],
"properties": {
"encrypted_content": {
"type": "string"
},
"type": {
"title": "EncryptedContentFunctionCallOutputContentItemType",
"type": "string",
"enum": [
"encrypted_content"
]
}
}
}
]
}Variants
InputText
InputTextFunctionCallOutputContentItem
InputImage
InputImageFunctionCallOutputContentItem
EncryptedContent
EncryptedContentFunctionCallOutputContentItem