LoginAccountParams

Enum LoginAccountParams 

pub enum LoginAccountParams {
    ApiKey {
        api_key: String,
    },
    Chatgpt {
        app_brand: Option<LoginAppBrand>,
        codex_streamlined_login: Option<bool>,
        use_hosted_login_success_page: Option<bool>,
    },
    ChatgptDeviceCode,
    ChatgptAuthTokens {
        access_token: String,
        chatgpt_account_id: String,
        chatgpt_plan_type: Option<String>,
    },
}
LoginAccountParams

JSON schema
{
 "title": "LoginAccountParams",
 "oneOf": [
   {
     "title": "ApiKeyv2::LoginAccountParams",
     "type": "object",
     "required": [
       "apiKey",
       "type"
     ],
     "properties": {
       "apiKey": {
         "type": "string"
       },
       "type": {
         "title": "ApiKeyv2::LoginAccountParamsType",
         "type": "string",
         "enum": [
           "apiKey"
         ]
       }
     }
   },
   {
     "title": "Chatgptv2::LoginAccountParams",
     "type": "object",
     "required": [
       "type"
     ],
     "properties": {
       "appBrand": {
         "default": null,
         "anyOf": [
           {
             "$ref": "#/definitions/LoginAppBrand"
           },
           {
             "type": "null"
           }
         ]
       },
       "codexStreamlinedLogin": {
         "type": "boolean"
       },
       "type": {
         "title": "Chatgptv2::LoginAccountParamsType",
         "type": "string",
         "enum": [
           "chatgpt"
         ]
       },
       "useHostedLoginSuccessPage": {
         "type": "boolean"
       }
     }
   },
   {
     "title": "ChatgptDeviceCodev2::LoginAccountParams",
     "type": "object",
     "required": [
       "type"
     ],
     "properties": {
       "type": {
         "title": "ChatgptDeviceCodev2::LoginAccountParamsType",
         "type": "string",
         "enum": [
           "chatgptDeviceCode"
         ]
       }
     }
   },
   {
     "title": "ChatgptAuthTokensv2::LoginAccountParams",
     "description": "[UNSTABLE] FOR OPENAI INTERNAL USE ONLY - DO NOT USE. The access token must contain the same scopes that Codex-managed ChatGPT auth tokens have.",
     "type": "object",
     "required": [
       "accessToken",
       "chatgptAccountId",
       "type"
     ],
     "properties": {
       "accessToken": {
         "description": "Access token (JWT) supplied by the client. This token is used for backend API requests and email extraction.",
         "type": "string"
       },
       "chatgptAccountId": {
         "description": "Workspace/account identifier supplied by the client.",
         "type": "string"
       },
       "chatgptPlanType": {
         "description": "Optional plan type supplied by the client.\n\nWhen `null`, Codex attempts to derive the plan type from access-token claims. If unavailable, the plan defaults to `unknown`.",
         "type": [
           "string",
           "null"
         ]
       },
       "type": {
         "title": "ChatgptAuthTokensv2::LoginAccountParamsType",
         "type": "string",
         "enum": [
           "chatgptAuthTokens"
         ]
       }
     }
   }
 ],
 "$schema": "http://json-schema.org/draft-07/schema#"
}

Variants



ApiKey

ApiKeyv2::LoginAccountParams

Fields

api_key: String


Chatgpt

Chatgptv2::LoginAccountParams

Fields

codex_streamlined_login: Option<bool>
use_hosted_login_success_page: Option<bool>


ChatgptDeviceCode



ChatgptAuthTokens

ChatgptAuthTokensv2::LoginAccountParams

[UNSTABLE] FOR OPENAI INTERNAL USE ONLY - DO NOT USE. The access token must contain the same scopes that Codex-managed ChatGPT auth tokens have.

Fields

access_token: String

Access token (JWT) supplied by the client. This token is used for backend API requests and email extraction.

chatgpt_account_id: String

Workspace/account identifier supplied by the client.

chatgpt_plan_type: Option<String>

Optional plan type supplied by the client.

When null, Codex attempts to derive the plan type from access-token claims. If unavailable, the plan defaults to unknown.