LoginAccountResponse

Enum LoginAccountResponse 

pub enum LoginAccountResponse {
    ApiKey,
    Chatgpt {
        auth_url: String,
        login_id: String,
    },
    ChatgptDeviceCode {
        login_id: String,
        user_code: String,
        verification_url: String,
    },
    ChatgptAuthTokens,
}
LoginAccountResponse

JSON schema
{
 "title": "LoginAccountResponse",
 "oneOf": [
   {
     "title": "ApiKeyv2::LoginAccountResponse",
     "type": "object",
     "required": [
       "type"
     ],
     "properties": {
       "type": {
         "title": "ApiKeyv2::LoginAccountResponseType",
         "type": "string",
         "enum": [
           "apiKey"
         ]
       }
     }
   },
   {
     "title": "Chatgptv2::LoginAccountResponse",
     "type": "object",
     "required": [
       "authUrl",
       "loginId",
       "type"
     ],
     "properties": {
       "authUrl": {
         "description": "URL the client should open in a browser to initiate the OAuth flow.",
         "type": "string"
       },
       "loginId": {
         "type": "string"
       },
       "type": {
         "title": "Chatgptv2::LoginAccountResponseType",
         "type": "string",
         "enum": [
           "chatgpt"
         ]
       }
     }
   },
   {
     "title": "ChatgptDeviceCodev2::LoginAccountResponse",
     "type": "object",
     "required": [
       "loginId",
       "type",
       "userCode",
       "verificationUrl"
     ],
     "properties": {
       "loginId": {
         "type": "string"
       },
       "type": {
         "title": "ChatgptDeviceCodev2::LoginAccountResponseType",
         "type": "string",
         "enum": [
           "chatgptDeviceCode"
         ]
       },
       "userCode": {
         "description": "One-time code the user must enter after signing in.",
         "type": "string"
       },
       "verificationUrl": {
         "description": "URL the client should open in a browser to complete device code authorization.",
         "type": "string"
       }
     }
   },
   {
     "title": "ChatgptAuthTokensv2::LoginAccountResponse",
     "type": "object",
     "required": [
       "type"
     ],
     "properties": {
       "type": {
         "title": "ChatgptAuthTokensv2::LoginAccountResponseType",
         "type": "string",
         "enum": [
           "chatgptAuthTokens"
         ]
       }
     }
   }
 ],
 "$schema": "http://json-schema.org/draft-07/schema#"
}

Variants



ApiKey



Chatgpt

Chatgptv2::LoginAccountResponse

Fields

auth_url: String

URL the client should open in a browser to initiate the OAuth flow.

login_id: String


ChatgptDeviceCode

ChatgptDeviceCodev2::LoginAccountResponse

Fields

login_id: String
user_code: String

One-time code the user must enter after signing in.

verification_url: String

URL the client should open in a browser to complete device code authorization.



ChatgptAuthTokens