pub enum MultiAgentMode {
ExplicitRequestOnly,
Proactive,
Custom(String),
}Expand description
Controls the effective multi-agent delegation instructions for a turn. custom means the configured mode hint defines the policy instead of a built-in policy.
JSON schema
{
"description": "Controls the effective multi-agent delegation instructions for a turn. `custom` means the configured mode hint defines the policy instead of a built-in policy.",
"oneOf": [
{
"type": "string",
"enum": [
"explicitRequestOnly",
"proactive"
]
},
{
"title": "CustomMultiAgentMode",
"type": "object",
"required": [
"custom"
],
"properties": {
"custom": {
"type": "string"
}
},
"additionalProperties": false
}
]
}Variants