ParsedCommand

Enum ParsedCommand 

pub enum ParsedCommand {
    Read {
        cmd: String,
        name: String,
        path: String,
    },
    ListFiles {
        cmd: String,
        path: Option<String>,
    },
    Search {
        cmd: String,
        path: Option<String>,
        query: Option<String>,
    },
    Unknown {
        cmd: String,
    },
}
ParsedCommand

JSON schema
{
 "oneOf": [
   {
     "title": "ReadParsedCommand",
     "type": "object",
     "required": [
       "cmd",
       "name",
       "path",
       "type"
     ],
     "properties": {
       "cmd": {
         "type": "string"
       },
       "name": {
         "type": "string"
       },
       "path": {
         "description": "(Best effort) Path to the file being read by the command. When possible, this is an absolute path, though when relative, it should be resolved against the `cwd`` that will be used to run the command to derive the absolute path.",
         "type": "string"
       },
       "type": {
         "title": "ReadParsedCommandType",
         "type": "string",
         "enum": [
           "read"
         ]
       }
     }
   },
   {
     "title": "ListFilesParsedCommand",
     "type": "object",
     "required": [
       "cmd",
       "type"
     ],
     "properties": {
       "cmd": {
         "type": "string"
       },
       "path": {
         "type": [
           "string",
           "null"
         ]
       },
       "type": {
         "title": "ListFilesParsedCommandType",
         "type": "string",
         "enum": [
           "list_files"
         ]
       }
     }
   },
   {
     "title": "SearchParsedCommand",
     "type": "object",
     "required": [
       "cmd",
       "type"
     ],
     "properties": {
       "cmd": {
         "type": "string"
       },
       "path": {
         "type": [
           "string",
           "null"
         ]
       },
       "query": {
         "type": [
           "string",
           "null"
         ]
       },
       "type": {
         "title": "SearchParsedCommandType",
         "type": "string",
         "enum": [
           "search"
         ]
       }
     }
   },
   {
     "title": "UnknownParsedCommand",
     "type": "object",
     "required": [
       "cmd",
       "type"
     ],
     "properties": {
       "cmd": {
         "type": "string"
       },
       "type": {
         "title": "UnknownParsedCommandType",
         "type": "string",
         "enum": [
           "unknown"
         ]
       }
     }
   }
 ]
}

Variants



Read

ReadParsedCommand

Fields

name: String
path: String

(Best effort) Path to the file being read by the command. When possible, this is an absolute path, though when relative, it should be resolved against the `cwd`` that will be used to run the command to derive the absolute path.



ListFiles

ListFilesParsedCommand

Fields



Search

SearchParsedCommand

Fields



Unknown

UnknownParsedCommand

Fields