ReviewTarget

Enum ReviewTarget 

pub enum ReviewTarget {
    UncommittedChanges,
    BaseBranch {
        branch: String,
    },
    Commit {
        sha: String,
        title: Option<String>,
    },
    Custom {
        instructions: String,
    },
}
ReviewTarget

JSON schema
{
 "oneOf": [
   {
     "title": "UncommittedChangesReviewTarget",
     "description": "Review the working tree: staged, unstaged, and untracked files.",
     "type": "object",
     "required": [
       "type"
     ],
     "properties": {
       "type": {
         "title": "UncommittedChangesReviewTargetType",
         "type": "string",
         "enum": [
           "uncommittedChanges"
         ]
       }
     }
   },
   {
     "title": "BaseBranchReviewTarget",
     "description": "Review changes between the current branch and the given base branch.",
     "type": "object",
     "required": [
       "branch",
       "type"
     ],
     "properties": {
       "branch": {
         "type": "string"
       },
       "type": {
         "title": "BaseBranchReviewTargetType",
         "type": "string",
         "enum": [
           "baseBranch"
         ]
       }
     }
   },
   {
     "title": "CommitReviewTarget",
     "description": "Review the changes introduced by a specific commit.",
     "type": "object",
     "required": [
       "sha",
       "type"
     ],
     "properties": {
       "sha": {
         "type": "string"
       },
       "title": {
         "description": "Optional human-readable label (e.g., commit subject) for UIs.",
         "type": [
           "string",
           "null"
         ]
       },
       "type": {
         "title": "CommitReviewTargetType",
         "type": "string",
         "enum": [
           "commit"
         ]
       }
     }
   },
   {
     "title": "CustomReviewTarget",
     "description": "Arbitrary instructions, equivalent to the old free-form prompt.",
     "type": "object",
     "required": [
       "instructions",
       "type"
     ],
     "properties": {
       "instructions": {
         "type": "string"
       },
       "type": {
         "title": "CustomReviewTargetType",
         "type": "string",
         "enum": [
           "custom"
         ]
       }
     }
   }
 ]
}

Variants



UncommittedChanges



BaseBranch

BaseBranchReviewTarget

Review changes between the current branch and the given base branch.

Fields

branch: String


Commit

CommitReviewTarget

Review the changes introduced by a specific commit.

Fields

title: Option<String>

Optional human-readable label (e.g., commit subject) for UIs.



Custom

CustomReviewTarget

Arbitrary instructions, equivalent to the old free-form prompt.

Fields

instructions: String