pub struct AccountRateLimitsUpdatedNotification {
pub rate_limits: RateLimitSnapshot,
}Expand description
Sparse rolling rate-limit update.
Clients should merge available values into the most recent account/rateLimits/read response or refetch that snapshot. Nullable account metadata may be unavailable in a rolling update and does not clear a previously observed value.
JSON schema
{
"title": "AccountRateLimitsUpdatedNotification",
"description": "Sparse rolling rate-limit update.\n\nClients should merge available values into the most recent `account/rateLimits/read` response or refetch that snapshot. Nullable account metadata may be unavailable in a rolling update and does not clear a previously observed value.",
"type": "object",
"required": [
"rateLimits"
],
"properties": {
"rateLimits": {
"$ref": "#/definitions/RateLimitSnapshot"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
rate_limits: RateLimitSnapshotTrait Implementations
Sourceimpl Clone for AccountRateLimitsUpdatedNotification
impl Clone for AccountRateLimitsUpdatedNotification
Sourcefn clone(&self) -> AccountRateLimitsUpdatedNotification
fn clone(&self) -> AccountRateLimitsUpdatedNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for AccountRateLimitsUpdatedNotification
impl<'de> Deserialize<'de> for AccountRateLimitsUpdatedNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<AccountRateLimitsUpdatedNotification> for ServerNotification
impl From<AccountRateLimitsUpdatedNotification> for ServerNotification
Sourcefn from(value: AccountRateLimitsUpdatedNotification) -> Self
fn from(value: AccountRateLimitsUpdatedNotification) -> Self
Converts to this type from the input type.