pub struct ApplyPatchApprovalParams {
pub call_id: String,
pub conversation_id: ThreadId,
pub file_changes: HashMap<String, FileChange>,
pub grant_root: Option<String>,
pub reason: Option<String>,
}Expand description
ApplyPatchApprovalParams
JSON schema
{
"title": "ApplyPatchApprovalParams",
"type": "object",
"required": [
"callId",
"conversationId",
"fileChanges"
],
"properties": {
"callId": {
"description": "Use to correlate this with [codex_protocol::protocol::PatchApplyBeginEvent] and [codex_protocol::protocol::PatchApplyEndEvent].",
"type": "string"
},
"conversationId": {
"$ref": "#/definitions/ThreadId"
},
"fileChanges": {
"type": "object",
"additionalProperties": {
"$ref": "#/definitions/FileChange"
}
},
"grantRoot": {
"description": "When set, the agent is asking the user to allow writes under this root for the remainder of the session (unclear if this is honored today).",
"type": [
"string",
"null"
]
},
"reason": {
"description": "Optional explanatory reason (e.g. request for extra write access).",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
call_id: StringUse to correlate this with [codex_protocol::protocol::PatchApplyBeginEvent] and [codex_protocol::protocol::PatchApplyEndEvent].
conversation_id: ThreadIdfile_changes: HashMap<String, FileChange>grant_root: Option<String>When set, the agent is asking the user to allow writes under this root for the remainder of the session (unclear if this is honored today).
reason: Option<String>Optional explanatory reason (e.g. request for extra write access).