pub struct AppsListParams {
pub cursor: Option<String>,
pub force_refetch: Option<bool>,
pub limit: Option<u32>,
pub thread_id: Option<String>,
}Expand description
EXPERIMENTAL - list available apps/connectors.
JSON schema
{
"title": "AppsListParams",
"description": "EXPERIMENTAL - list available apps/connectors.",
"type": "object",
"properties": {
"cursor": {
"description": "Opaque pagination cursor returned by a previous call.",
"type": [
"string",
"null"
]
},
"forceRefetch": {
"description": "When true, bypass app caches and fetch the latest data from sources.",
"type": "boolean"
},
"limit": {
"description": "Optional page size; defaults to a reasonable server-side value.",
"type": [
"integer",
"null"
],
"format": "uint32",
"minimum": 0.0
},
"threadId": {
"description": "Optional thread id used to evaluate app feature gating from that thread's config.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cursor: Option<String>Opaque pagination cursor returned by a previous call.
force_refetch: Option<bool>When true, bypass app caches and fetch the latest data from sources.
limit: Option<u32>Optional page size; defaults to a reasonable server-side value.
thread_id: Option<String>Optional thread id used to evaluate app feature gating from that thread’s config.