pub struct AppsListResponse {
pub data: Vec<AppInfo>,
pub next_cursor: Option<String>,
}Expand description
EXPERIMENTAL - app list response.
JSON schema
{
"title": "AppsListResponse",
"description": "EXPERIMENTAL - app list response.",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"type": "array",
"items": {
"$ref": "#/definitions/AppInfo"
}
},
"nextCursor": {
"description": "Opaque cursor to pass to the next call to continue after the last item. If None, there are no more items to return.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
data: Vec<AppInfo>next_cursor: Option<String>Opaque cursor to pass to the next call to continue after the last item. If None, there are no more items to return.