pub struct ChatgptAuthTokensRefreshParams {
pub previous_account_id: Option<String>,
pub reason: ChatgptAuthTokensRefreshReason,
}Expand description
ChatgptAuthTokensRefreshParams
JSON schema
{
"title": "ChatgptAuthTokensRefreshParams",
"type": "object",
"required": [
"reason"
],
"properties": {
"previousAccountId": {
"description": "Workspace/account identifier that Codex was previously using.\n\nClients that manage multiple accounts/workspaces can use this as a hint to refresh the token for the correct workspace.\n\nThis may be `null` when the prior auth state did not include a workspace identifier (`chatgpt_account_id`).",
"type": [
"string",
"null"
]
},
"reason": {
"$ref": "#/definitions/ChatgptAuthTokensRefreshReason"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
previous_account_id: Option<String>Workspace/account identifier that Codex was previously using.
Clients that manage multiple accounts/workspaces can use this as a hint to refresh the token for the correct workspace.
This may be null when the prior auth state did not include a workspace identifier (chatgpt_account_id).
reason: ChatgptAuthTokensRefreshReasonTrait Implementations
Sourceimpl Clone for ChatgptAuthTokensRefreshParams
impl Clone for ChatgptAuthTokensRefreshParams
Sourcefn clone(&self) -> ChatgptAuthTokensRefreshParams
fn clone(&self) -> ChatgptAuthTokensRefreshParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ChatgptAuthTokensRefreshParams
impl<'de> Deserialize<'de> for ChatgptAuthTokensRefreshParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more