pub struct CommandExecOutputDeltaNotification {
pub cap_reached: bool,
pub delta_base64: String,
pub process_id: String,
pub stream: CommandExecOutputStream,
}Expand description
Base64-encoded output chunk emitted for a streaming command/exec request.
These notifications are connection-scoped. If the originating connection closes, the server terminates the process.
JSON schema
{
"title": "CommandExecOutputDeltaNotification",
"description": "Base64-encoded output chunk emitted for a streaming `command/exec` request.\n\nThese notifications are connection-scoped. If the originating connection closes, the server terminates the process.",
"type": "object",
"required": [
"capReached",
"deltaBase64",
"processId",
"stream"
],
"properties": {
"capReached": {
"description": "`true` on the final streamed chunk for a stream when `outputBytesCap` truncated later output on that stream.",
"type": "boolean"
},
"deltaBase64": {
"description": "Base64-encoded output bytes.",
"type": "string"
},
"processId": {
"description": "Client-supplied, connection-scoped `processId` from the original `command/exec` request.",
"type": "string"
},
"stream": {
"description": "Output stream for this chunk.",
"allOf": [
{
"$ref": "#/definitions/CommandExecOutputStream"
}
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cap_reached: booltrue on the final streamed chunk for a stream when outputBytesCap truncated later output on that stream.
delta_base64: StringBase64-encoded output bytes.
process_id: StringClient-supplied, connection-scoped processId from the original command/exec request.
stream: CommandExecOutputStreamOutput stream for this chunk.