Config

Struct Config 

pub struct Config {
Show 24 fields pub analytics: Option<AnalyticsConfig>, pub approval_policy: Option<AskForApproval>, pub approvals_reviewer: Option<ApprovalsReviewer>, pub apps: Option<AppsConfig>, pub compact_prompt: Option<String>, pub desktop: Option<Map<String, Value>>, pub developer_instructions: Option<String>, pub forced_chatgpt_workspace_id: Option<ForcedChatgptWorkspaceIds>, pub forced_login_method: Option<ForcedLoginMethod>, pub instructions: Option<String>, pub model: Option<String>, pub model_auto_compact_token_limit: Option<i64>, pub model_auto_compact_token_limit_scope: Option<AutoCompactTokenLimitScope>, pub model_context_window: Option<i64>, pub model_provider: Option<String>, pub model_reasoning_effort: Option<ReasoningEffort>, pub model_reasoning_summary: Option<ReasoningSummary>, pub model_verbosity: Option<Verbosity>, pub review_model: Option<String>, pub sandbox_mode: Option<SandboxMode>, pub sandbox_workspace_write: Option<SandboxWorkspaceWrite>, pub service_tier: Option<String>, pub tools: Option<ToolsV2>, pub web_search: Option<WebSearchMode>,
}
Config

JSON schema
{
 "type": "object",
 "properties": {
   "analytics": {
     "anyOf": [
       {
         "$ref": "#/definitions/AnalyticsConfig"
       },
       {
         "type": "null"
       }
     ]
   },
   "approval_policy": {
     "anyOf": [
       {
         "$ref": "#/definitions/AskForApproval"
       },
       {
         "type": "null"
       }
     ]
   },
   "approvals_reviewer": {
     "description": "[UNSTABLE] Optional default for where approval requests are routed for review.",
     "anyOf": [
       {
         "$ref": "#/definitions/ApprovalsReviewer"
       },
       {
         "type": "null"
       }
     ]
   },
   "apps": {
     "default": null,
     "anyOf": [
       {
         "$ref": "#/definitions/AppsConfig"
       },
       {
         "type": "null"
       }
     ]
   },
   "compact_prompt": {
     "type": [
       "string",
       "null"
     ]
   },
   "desktop": {
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": true
   },
   "developer_instructions": {
     "type": [
       "string",
       "null"
     ]
   },
   "forced_chatgpt_workspace_id": {
     "anyOf": [
       {
         "$ref": "#/definitions/ForcedChatgptWorkspaceIds"
       },
       {
         "type": "null"
       }
     ]
   },
   "forced_login_method": {
     "anyOf": [
       {
         "$ref": "#/definitions/ForcedLoginMethod"
       },
       {
         "type": "null"
       }
     ]
   },
   "instructions": {
     "type": [
       "string",
       "null"
     ]
   },
   "model": {
     "type": [
       "string",
       "null"
     ]
   },
   "model_auto_compact_token_limit": {
     "type": [
       "integer",
       "null"
     ],
     "format": "int64"
   },
   "model_auto_compact_token_limit_scope": {
     "anyOf": [
       {
         "$ref": "#/definitions/AutoCompactTokenLimitScope"
       },
       {
         "type": "null"
       }
     ]
   },
   "model_context_window": {
     "type": [
       "integer",
       "null"
     ],
     "format": "int64"
   },
   "model_provider": {
     "type": [
       "string",
       "null"
     ]
   },
   "model_reasoning_effort": {
     "anyOf": [
       {
         "$ref": "#/definitions/ReasoningEffort"
       },
       {
         "type": "null"
       }
     ]
   },
   "model_reasoning_summary": {
     "anyOf": [
       {
         "$ref": "#/definitions/ReasoningSummary"
       },
       {
         "type": "null"
       }
     ]
   },
   "model_verbosity": {
     "anyOf": [
       {
         "$ref": "#/definitions/Verbosity"
       },
       {
         "type": "null"
       }
     ]
   },
   "review_model": {
     "type": [
       "string",
       "null"
     ]
   },
   "sandbox_mode": {
     "anyOf": [
       {
         "$ref": "#/definitions/SandboxMode"
       },
       {
         "type": "null"
       }
     ]
   },
   "sandbox_workspace_write": {
     "anyOf": [
       {
         "$ref": "#/definitions/SandboxWorkspaceWrite"
       },
       {
         "type": "null"
       }
     ]
   },
   "service_tier": {
     "type": [
       "string",
       "null"
     ]
   },
   "tools": {
     "anyOf": [
       {
         "$ref": "#/definitions/ToolsV2"
       },
       {
         "type": "null"
       }
     ]
   },
   "web_search": {
     "anyOf": [
       {
         "$ref": "#/definitions/WebSearchMode"
       },
       {
         "type": "null"
       }
     ]
   }
 },
 "additionalProperties": true
}

Fields

analytics: Option<AnalyticsConfig>approval_policy: Option<AskForApproval>approvals_reviewer: Option<ApprovalsReviewer>

[UNSTABLE] Optional default for where approval requests are routed for review.

apps: Option<AppsConfig>compact_prompt: Option<String>desktop: Option<Map<String, Value>>developer_instructions: Option<String>forced_chatgpt_workspace_id: Option<ForcedChatgptWorkspaceIds>forced_login_method: Option<ForcedLoginMethod>instructions: Option<String>model: Option<String>model_auto_compact_token_limit: Option<i64>model_auto_compact_token_limit_scope: Option<AutoCompactTokenLimitScope>model_context_window: Option<i64>model_provider: Option<String>model_reasoning_effort: Option<ReasoningEffort>model_reasoning_summary: Option<ReasoningSummary>model_verbosity: Option<Verbosity>review_model: Option<String>sandbox_mode: Option<SandboxMode>sandbox_workspace_write: Option<SandboxWorkspaceWrite>service_tier: Option<String>tools: Option<ToolsV2>web_search: Option<WebSearchMode>