pub struct EnvironmentInfoResponse {
pub cwd: Option<PathUri>,
pub shell: EnvironmentShellInfo,
}Expand description
EnvironmentInfoResponse
JSON schema
{
"title": "EnvironmentInfoResponse",
"type": "object",
"required": [
"shell"
],
"properties": {
"cwd": {
"description": "Default working directory reported by the environment, as a canonical file URI.",
"anyOf": [
{
"$ref": "#/definitions/PathUri"
},
{
"type": "null"
}
]
},
"shell": {
"$ref": "#/definitions/EnvironmentShellInfo"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cwd: Option<PathUri>Default working directory reported by the environment, as a canonical file URI.
shell: EnvironmentShellInfoTrait Implementations
Sourceimpl Clone for EnvironmentInfoResponse
impl Clone for EnvironmentInfoResponse
Sourcefn clone(&self) -> EnvironmentInfoResponse
fn clone(&self) -> EnvironmentInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnvironmentInfoResponse
impl Debug for EnvironmentInfoResponse
Sourceimpl<'de> Deserialize<'de> for EnvironmentInfoResponse
impl<'de> Deserialize<'de> for EnvironmentInfoResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more