pub struct ExperimentalFeatureEnablementSetParams {
pub enablement: HashMap<String, bool>,
}Expand description
ExperimentalFeatureEnablementSetParams
JSON schema
{
"title": "ExperimentalFeatureEnablementSetParams",
"type": "object",
"required": [
"enablement"
],
"properties": {
"enablement": {
"description": "Process-wide runtime feature enablement keyed by canonical feature name.\n\nOnly named features are updated. Omitted features are left unchanged. Send an empty map for a no-op.",
"type": "object",
"additionalProperties": {
"type": "boolean"
}
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
enablement: HashMap<String, bool>Process-wide runtime feature enablement keyed by canonical feature name.
Only named features are updated. Omitted features are left unchanged. Send an empty map for a no-op.