pub struct ExperimentalFeatureListParams {
pub cursor: Option<String>,
pub limit: Option<u32>,
pub thread_id: Option<String>,
}Expand description
ExperimentalFeatureListParams
JSON schema
{
"title": "ExperimentalFeatureListParams",
"type": "object",
"properties": {
"cursor": {
"description": "Opaque pagination cursor returned by a previous call.",
"type": [
"string",
"null"
]
},
"limit": {
"description": "Optional page size; defaults to a reasonable server-side value.",
"type": [
"integer",
"null"
],
"format": "uint32",
"minimum": 0.0
},
"threadId": {
"description": "Optional loaded thread id. Pass this when showing feature state for an existing thread so enablement is computed from that thread's refreshed config, including project-local config for the thread's cwd.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cursor: Option<String>Opaque pagination cursor returned by a previous call.
limit: Option<u32>Optional page size; defaults to a reasonable server-side value.
thread_id: Option<String>Optional loaded thread id. Pass this when showing feature state for an existing thread so enablement is computed from that thread’s refreshed config, including project-local config for the thread’s cwd.