pub struct FsGetMetadataResponse {
pub created_at_ms: i64,
pub is_directory: bool,
pub is_file: bool,
pub is_symlink: bool,
pub modified_at_ms: i64,
}Expand description
Metadata returned by fs/getMetadata.
JSON schema
{
"title": "FsGetMetadataResponse",
"description": "Metadata returned by `fs/getMetadata`.",
"type": "object",
"required": [
"createdAtMs",
"isDirectory",
"isFile",
"isSymlink",
"modifiedAtMs"
],
"properties": {
"createdAtMs": {
"description": "File creation time in Unix milliseconds when available, otherwise `0`.",
"type": "integer",
"format": "int64"
},
"isDirectory": {
"description": "Whether the path resolves to a directory.",
"type": "boolean"
},
"isFile": {
"description": "Whether the path resolves to a regular file.",
"type": "boolean"
},
"isSymlink": {
"description": "Whether the path itself is a symbolic link.",
"type": "boolean"
},
"modifiedAtMs": {
"description": "File modification time in Unix milliseconds when available, otherwise `0`.",
"type": "integer",
"format": "int64"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
created_at_ms: i64File creation time in Unix milliseconds when available, otherwise 0.
is_directory: boolWhether the path resolves to a directory.
is_file: boolWhether the path resolves to a regular file.
is_symlink: boolWhether the path itself is a symbolic link.
modified_at_ms: i64File modification time in Unix milliseconds when available, otherwise 0.