pub struct FuzzyFileSearchSessionUpdateResponse(pub Map<String, Value>);Expand description
FuzzyFileSearchSessionUpdateResponse
JSON schema
{
"title": "FuzzyFileSearchSessionUpdateResponse",
"type": "object",
"$schema": "http://json-schema.org/draft-07/schema#"
}Tuple Fields
0: Map<String, Value>Methods from Deref<Target = Map<String, Value>>
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&Value>
pub fn get<Q>(&self, key: &Q) -> Option<&Value>
Returns a reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains a value for the specified key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.