pub struct GetAccountParams {
pub refresh_token: Option<bool>,
}Expand description
GetAccountParams
JSON schema
{
"title": "GetAccountParams",
"type": "object",
"properties": {
"refreshToken": {
"description": "When `true`, requests a proactive token refresh before returning.\n\nIn managed auth mode this triggers the normal refresh-token flow. In external auth mode this flag is ignored. Clients should refresh tokens themselves and call `account/login/start` with `chatgptAuthTokens`.",
"type": "boolean"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
refresh_token: Option<bool>When true, requests a proactive token refresh before returning.
In managed auth mode this triggers the normal refresh-token flow. In external auth mode this flag is ignored. Clients should refresh tokens themselves and call account/login/start with chatgptAuthTokens.