pub struct HooksListParams {
pub cwds: Vec<String>,
}Expand description
HooksListParams
JSON schema
{
"title": "HooksListParams",
"type": "object",
"properties": {
"cwds": {
"description": "When empty, defaults to the current session working directory.",
"type": "array",
"items": {
"type": "string"
}
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cwds: Vec<String>When empty, defaults to the current session working directory.