pub struct ListMcpServerStatusResponse {
pub data: Vec<McpServerStatus>,
pub next_cursor: Option<String>,
}Expand description
ListMcpServerStatusResponse
JSON schema
{
"title": "ListMcpServerStatusResponse",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"type": "array",
"items": {
"$ref": "#/definitions/McpServerStatus"
}
},
"nextCursor": {
"description": "Opaque cursor to pass to the next call to continue after the last item. If None, there are no more items to return.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
data: Vec<McpServerStatus>next_cursor: Option<String>Opaque cursor to pass to the next call to continue after the last item. If None, there are no more items to return.