pub struct ModelListParams {
pub cursor: Option<String>,
pub include_hidden: Option<bool>,
pub limit: Option<u32>,
}Expand description
ModelListParams
JSON schema
{
"title": "ModelListParams",
"type": "object",
"properties": {
"cursor": {
"description": "Opaque pagination cursor returned by a previous call.",
"type": [
"string",
"null"
]
},
"includeHidden": {
"description": "When true, include models that are hidden from the default picker list.",
"type": [
"boolean",
"null"
]
},
"limit": {
"description": "Optional page size; defaults to a reasonable server-side value.",
"type": [
"integer",
"null"
],
"format": "uint32",
"minimum": 0.0
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cursor: Option<String>Opaque pagination cursor returned by a previous call.
When true, include models that are hidden from the default picker list.
limit: Option<u32>Optional page size; defaults to a reasonable server-side value.