NetworkRequirements

Struct NetworkRequirements 

pub struct NetworkRequirements {
Show 13 fields pub allow_local_binding: Option<bool>, pub allow_unix_sockets: Option<Vec<String>>, pub allow_upstream_proxy: Option<bool>, pub allowed_domains: Option<Vec<String>>, pub dangerously_allow_all_unix_sockets: Option<bool>, pub dangerously_allow_non_loopback_proxy: Option<bool>, pub denied_domains: Option<Vec<String>>, pub domains: Option<HashMap<String, NetworkDomainPermission>>, pub enabled: Option<bool>, pub http_port: Option<u16>, pub managed_allowed_domains_only: Option<bool>, pub socks_port: Option<u16>, pub unix_sockets: Option<HashMap<String, NetworkUnixSocketPermission>>,
}
NetworkRequirements

JSON schema
{
 "type": "object",
 "properties": {
   "allowLocalBinding": {
     "type": [
       "boolean",
       "null"
     ]
   },
   "allowUnixSockets": {
     "description": "Legacy compatibility view derived from `unix_sockets`.",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "type": "string"
     }
   },
   "allowUpstreamProxy": {
     "type": [
       "boolean",
       "null"
     ]
   },
   "allowedDomains": {
     "description": "Legacy compatibility view derived from `domains`.",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "type": "string"
     }
   },
   "dangerouslyAllowAllUnixSockets": {
     "type": [
       "boolean",
       "null"
     ]
   },
   "dangerouslyAllowNonLoopbackProxy": {
     "type": [
       "boolean",
       "null"
     ]
   },
   "deniedDomains": {
     "description": "Legacy compatibility view derived from `domains`.",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "type": "string"
     }
   },
   "domains": {
     "description": "Canonical network permission map for `experimental_network`.",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": {
       "$ref": "#/definitions/NetworkDomainPermission"
     }
   },
   "enabled": {
     "type": [
       "boolean",
       "null"
     ]
   },
   "httpPort": {
     "type": [
       "integer",
       "null"
     ],
     "format": "uint16",
     "minimum": 0.0
   },
   "managedAllowedDomainsOnly": {
     "description": "When true, only managed allowlist entries are respected while managed network enforcement is active.",
     "type": [
       "boolean",
       "null"
     ]
   },
   "socksPort": {
     "type": [
       "integer",
       "null"
     ],
     "format": "uint16",
     "minimum": 0.0
   },
   "unixSockets": {
     "description": "Canonical unix socket permission map for `experimental_network`.",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": {
       "$ref": "#/definitions/NetworkUnixSocketPermission"
     }
   }
 }
}

Fields

allow_local_binding: Option<bool>allow_unix_sockets: Option<Vec<String>>

Legacy compatibility view derived from unix_sockets.

allow_upstream_proxy: Option<bool>allowed_domains: Option<Vec<String>>

Legacy compatibility view derived from domains.

dangerously_allow_all_unix_sockets: Option<bool>dangerously_allow_non_loopback_proxy: Option<bool>denied_domains: Option<Vec<String>>

Legacy compatibility view derived from domains.

domains: Option<HashMap<String, NetworkDomainPermission>>

Canonical network permission map for experimental_network.

enabled: Option<bool>http_port: Option<u16>managed_allowed_domains_only: Option<bool>

When true, only managed allowlist entries are respected while managed network enforcement is active.

socks_port: Option<u16>unix_sockets: Option<HashMap<String, NetworkUnixSocketPermission>>

Canonical unix socket permission map for experimental_network.