pub struct PlanDeltaNotification {
pub delta: String,
pub item_id: String,
pub thread_id: String,
pub turn_id: String,
}Expand description
EXPERIMENTAL - proposed plan streaming deltas for plan items. Clients should not assume concatenated deltas match the completed plan item content.
JSON schema
{
"title": "PlanDeltaNotification",
"description": "EXPERIMENTAL - proposed plan streaming deltas for plan items. Clients should not assume concatenated deltas match the completed plan item content.",
"type": "object",
"required": [
"delta",
"itemId",
"threadId",
"turnId"
],
"properties": {
"delta": {
"type": "string"
},
"itemId": {
"type": "string"
},
"threadId": {
"type": "string"
},
"turnId": {
"type": "string"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
delta: Stringitem_id: Stringthread_id: Stringturn_id: StringTrait Implementations
Sourceimpl Clone for PlanDeltaNotification
impl Clone for PlanDeltaNotification
Sourcefn clone(&self) -> PlanDeltaNotification
fn clone(&self) -> PlanDeltaNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanDeltaNotification
impl Debug for PlanDeltaNotification
Sourceimpl<'de> Deserialize<'de> for PlanDeltaNotification
impl<'de> Deserialize<'de> for PlanDeltaNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PlanDeltaNotification> for ServerNotification
impl From<PlanDeltaNotification> for ServerNotification
Sourcefn from(value: PlanDeltaNotification) -> Self
fn from(value: PlanDeltaNotification) -> Self
Converts to this type from the input type.