PluginInstalledParams

Struct PluginInstalledParams 

pub struct PluginInstalledParams {
    pub cwds: Option<Vec<AbsolutePathBuf>>,
    pub install_suggestion_plugin_names: Option<Vec<String>>,
}
PluginInstalledParams

JSON schema
{
 "title": "PluginInstalledParams",
 "type": "object",
 "properties": {
   "cwds": {
     "description": "Optional working directories used to discover repo marketplaces.",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "$ref": "#/definitions/AbsolutePathBuf"
     }
   },
   "installSuggestionPluginNames": {
     "description": "Additional uninstalled plugin names that should be returned when present locally. This is used by mention surfaces that intentionally expose install entrypoints.",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "type": "string"
     }
   }
 },
 "$schema": "http://json-schema.org/draft-07/schema#"
}

Fields

cwds: Option<Vec<AbsolutePathBuf>>

Optional working directories used to discover repo marketplaces.

install_suggestion_plugin_names: Option<Vec<String>>

Additional uninstalled plugin names that should be returned when present locally. This is used by mention surfaces that intentionally expose install entrypoints.