PluginInterface

Struct PluginInterface 

pub struct PluginInterface {
Show 19 fields pub brand_color: Option<String>, pub capabilities: Vec<String>, pub category: Option<String>, pub composer_icon: Option<AbsolutePathBuf>, pub composer_icon_url: Option<String>, pub default_prompt: Option<Vec<String>>, pub developer_name: Option<String>, pub display_name: Option<String>, pub logo: Option<AbsolutePathBuf>, pub logo_dark: Option<AbsolutePathBuf>, pub logo_url: Option<String>, pub logo_url_dark: Option<String>, pub long_description: Option<String>, pub privacy_policy_url: Option<String>, pub screenshot_urls: Vec<String>, pub screenshots: Vec<AbsolutePathBuf>, pub short_description: Option<String>, pub terms_of_service_url: Option<String>, pub website_url: Option<String>,
}
PluginInterface

JSON schema
{
 "type": "object",
 "required": [
   "capabilities",
   "screenshotUrls",
   "screenshots"
 ],
 "properties": {
   "brandColor": {
     "type": [
       "string",
       "null"
     ]
   },
   "capabilities": {
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "category": {
     "type": [
       "string",
       "null"
     ]
   },
   "composerIcon": {
     "description": "Local composer icon path, resolved from the installed plugin package.",
     "anyOf": [
       {
         "$ref": "#/definitions/AbsolutePathBuf"
       },
       {
         "type": "null"
       }
     ]
   },
   "composerIconUrl": {
     "description": "Remote composer icon URL from the plugin catalog.",
     "type": [
       "string",
       "null"
     ]
   },
   "defaultPrompt": {
     "description": "Starter prompts for the plugin. Capped at 3 entries with a maximum of 128 characters per entry.",
     "type": [
       "array",
       "null"
     ],
     "items": {
       "type": "string"
     }
   },
   "developerName": {
     "type": [
       "string",
       "null"
     ]
   },
   "displayName": {
     "type": [
       "string",
       "null"
     ]
   },
   "logo": {
     "description": "Local logo path, resolved from the installed plugin package.",
     "anyOf": [
       {
         "$ref": "#/definitions/AbsolutePathBuf"
       },
       {
         "type": "null"
       }
     ]
   },
   "logoDark": {
     "description": "Local dark-mode logo path, resolved from the installed plugin package.",
     "anyOf": [
       {
         "$ref": "#/definitions/AbsolutePathBuf"
       },
       {
         "type": "null"
       }
     ]
   },
   "logoUrl": {
     "description": "Remote logo URL from the plugin catalog.",
     "type": [
       "string",
       "null"
     ]
   },
   "logoUrlDark": {
     "description": "Remote dark-mode logo URL from the plugin catalog.",
     "type": [
       "string",
       "null"
     ]
   },
   "longDescription": {
     "type": [
       "string",
       "null"
     ]
   },
   "privacyPolicyUrl": {
     "type": [
       "string",
       "null"
     ]
   },
   "screenshotUrls": {
     "description": "Remote screenshot URLs from the plugin catalog.",
     "type": "array",
     "items": {
       "type": "string"
     }
   },
   "screenshots": {
     "description": "Local screenshot paths, resolved from the installed plugin package.",
     "type": "array",
     "items": {
       "$ref": "#/definitions/AbsolutePathBuf"
     }
   },
   "shortDescription": {
     "type": [
       "string",
       "null"
     ]
   },
   "termsOfServiceUrl": {
     "type": [
       "string",
       "null"
     ]
   },
   "websiteUrl": {
     "type": [
       "string",
       "null"
     ]
   }
 }
}

Fields

brand_color: Option<String>capabilities: Vec<String>category: Option<String>composer_icon: Option<AbsolutePathBuf>

Local composer icon path, resolved from the installed plugin package.

composer_icon_url: Option<String>

Remote composer icon URL from the plugin catalog.

default_prompt: Option<Vec<String>>

Starter prompts for the plugin. Capped at 3 entries with a maximum of 128 characters per entry.

developer_name: Option<String>display_name: Option<String>

Local logo path, resolved from the installed plugin package.

logo_dark: Option<AbsolutePathBuf>

Local dark-mode logo path, resolved from the installed plugin package.

logo_url: Option<String>

Remote logo URL from the plugin catalog.

logo_url_dark: Option<String>

Remote dark-mode logo URL from the plugin catalog.

long_description: Option<String>privacy_policy_url: Option<String>screenshot_urls: Vec<String>

Remote screenshot URLs from the plugin catalog.

screenshots: Vec<AbsolutePathBuf>

Local screenshot paths, resolved from the installed plugin package.

short_description: Option<String>terms_of_service_url: Option<String>website_url: Option<String>