pub struct PluginListParams {
pub cwds: Option<Vec<AbsolutePathBuf>>,
pub marketplace_kinds: Option<Vec<PluginListMarketplaceKind>>,
}Expand description
PluginListParams
JSON schema
{
"title": "PluginListParams",
"type": "object",
"properties": {
"cwds": {
"description": "Optional working directories used to discover repo marketplaces. When omitted, only home-scoped marketplaces and the official curated marketplace are considered.",
"type": [
"array",
"null"
],
"items": {
"$ref": "#/definitions/AbsolutePathBuf"
}
},
"marketplaceKinds": {
"description": "Optional marketplace kind filter. When omitted, only local marketplaces are queried, plus the default remote catalog when enabled by feature flag.",
"type": [
"array",
"null"
],
"items": {
"$ref": "#/definitions/PluginListMarketplaceKind"
}
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cwds: Option<Vec<AbsolutePathBuf>>Optional working directories used to discover repo marketplaces. When omitted, only home-scoped marketplaces and the official curated marketplace are considered.
marketplace_kinds: Option<Vec<PluginListMarketplaceKind>>Optional marketplace kind filter. When omitted, only local marketplaces are queried, plus the default remote catalog when enabled by feature flag.