PluginMarketplaceEntry

Struct PluginMarketplaceEntry 

pub struct PluginMarketplaceEntry {
    pub interface: Option<MarketplaceInterface>,
    pub name: String,
    pub path: Option<AbsolutePathBuf>,
    pub plugins: Vec<PluginSummary>,
}
PluginMarketplaceEntry

JSON schema
{
 "type": "object",
 "required": [
   "name",
   "plugins"
 ],
 "properties": {
   "interface": {
     "anyOf": [
       {
         "$ref": "#/definitions/MarketplaceInterface"
       },
       {
         "type": "null"
       }
     ]
   },
   "name": {
     "type": "string"
   },
   "path": {
     "description": "Local marketplace file path when the marketplace is backed by a local file. Remote-only catalog marketplaces do not have a local path.",
     "anyOf": [
       {
         "$ref": "#/definitions/AbsolutePathBuf"
       },
       {
         "type": "null"
       }
     ]
   },
   "plugins": {
     "type": "array",
     "items": {
       "$ref": "#/definitions/PluginSummary"
     }
   }
 }
}

Fields

interface: Option<MarketplaceInterface>name: Stringpath: Option<AbsolutePathBuf>

Local marketplace file path when the marketplace is backed by a local file. Remote-only catalog marketplaces do not have a local path.

plugins: Vec<PluginSummary>