PluginShareContext

Struct PluginShareContext 

pub struct PluginShareContext {
    pub creator_account_user_id: Option<String>,
    pub creator_name: Option<String>,
    pub discoverability: Option<PluginShareDiscoverability>,
    pub remote_plugin_id: String,
    pub remote_version: Option<String>,
    pub share_principals: Option<Vec<PluginSharePrincipal>>,
    pub share_url: Option<String>,
}
PluginShareContext

JSON schema
{
 "type": "object",
 "required": [
   "remotePluginId"
 ],
 "properties": {
   "creatorAccountUserId": {
     "type": [
       "string",
       "null"
     ]
   },
   "creatorName": {
     "type": [
       "string",
       "null"
     ]
   },
   "discoverability": {
     "anyOf": [
       {
         "$ref": "#/definitions/PluginShareDiscoverability"
       },
       {
         "type": "null"
       }
     ]
   },
   "remotePluginId": {
     "type": "string"
   },
   "remoteVersion": {
     "description": "Version of the remote shared plugin release when available.",
     "default": null,
     "type": [
       "string",
       "null"
     ]
   },
   "sharePrincipals": {
     "type": [
       "array",
       "null"
     ],
     "items": {
       "$ref": "#/definitions/PluginSharePrincipal"
     }
   },
   "shareUrl": {
     "type": [
       "string",
       "null"
     ]
   }
 }
}

Fields

creator_account_user_id: Option<String>creator_name: Option<String>discoverability: Option<PluginShareDiscoverability>remote_plugin_id: Stringremote_version: Option<String>

Version of the remote shared plugin release when available.

share_principals: Option<Vec<PluginSharePrincipal>>share_url: Option<String>