pub struct PluginSummary {Show 15 fields
pub auth_policy: PluginAuthPolicy,
pub availability: PluginAvailability,
pub enabled: bool,
pub id: String,
pub install_policy: PluginInstallPolicy,
pub install_policy_source: Option<PluginInstallPolicySource>,
pub installed: bool,
pub interface: Option<PluginInterface>,
pub keywords: Vec<String>,
pub local_version: Option<String>,
pub name: String,
pub remote_plugin_id: Option<String>,
pub share_context: Option<PluginShareContext>,
pub source: PluginSource,
pub version: Option<String>,
}Expand description
PluginSummary
JSON schema
{
"type": "object",
"required": [
"authPolicy",
"enabled",
"id",
"installPolicy",
"installed",
"name",
"source"
],
"properties": {
"authPolicy": {
"$ref": "#/definitions/PluginAuthPolicy"
},
"availability": {
"description": "Availability state for installing and using the plugin.",
"default": "AVAILABLE",
"allOf": [
{
"$ref": "#/definitions/PluginAvailability"
}
]
},
"enabled": {
"type": "boolean"
},
"id": {
"type": "string"
},
"installPolicy": {
"$ref": "#/definitions/PluginInstallPolicy"
},
"installPolicySource": {
"anyOf": [
{
"$ref": "#/definitions/PluginInstallPolicySource"
},
{
"type": "null"
}
]
},
"installed": {
"type": "boolean"
},
"interface": {
"anyOf": [
{
"$ref": "#/definitions/PluginInterface"
},
{
"type": "null"
}
]
},
"keywords": {
"default": [],
"type": "array",
"items": {
"type": "string"
}
},
"localVersion": {
"description": "Version of the locally materialized plugin package when available.",
"default": null,
"type": [
"string",
"null"
]
},
"name": {
"type": "string"
},
"remotePluginId": {
"description": "Backend remote plugin identifier when available.",
"type": [
"string",
"null"
]
},
"shareContext": {
"description": "Remote sharing context associated with this plugin when available.",
"anyOf": [
{
"$ref": "#/definitions/PluginShareContext"
},
{
"type": "null"
}
]
},
"source": {
"$ref": "#/definitions/PluginSource"
},
"version": {
"description": "Version advertised by the remote marketplace backend when available.",
"default": null,
"type": [
"string",
"null"
]
}
}
}Fields
auth_policy: PluginAuthPolicyavailability: PluginAvailabilityAvailability state for installing and using the plugin.
enabled: boolid: Stringinstall_policy: PluginInstallPolicyinstall_policy_source: Option<PluginInstallPolicySource>installed: boolinterface: Option<PluginInterface>keywords: Vec<String>local_version: Option<String>Version of the locally materialized plugin package when available.
name: Stringremote_plugin_id: Option<String>Backend remote plugin identifier when available.
Remote sharing context associated with this plugin when available.
source: PluginSourceversion: Option<String>Version advertised by the remote marketplace backend when available.