ProcessExitedNotification

Struct ProcessExitedNotification 

pub struct ProcessExitedNotification {
    pub exit_code: i32,
    pub process_handle: String,
    pub stderr: String,
    pub stderr_cap_reached: bool,
    pub stdout: String,
    pub stdout_cap_reached: bool,
}
Final process exit notification for process/spawn.

JSON schema
{
 "title": "ProcessExitedNotification",
 "description": "Final process exit notification for `process/spawn`.",
 "type": "object",
 "required": [
   "exitCode",
   "processHandle",
   "stderr",
   "stderrCapReached",
   "stdout",
   "stdoutCapReached"
 ],
 "properties": {
   "exitCode": {
     "description": "Process exit code.",
     "type": "integer",
     "format": "int32"
   },
   "processHandle": {
     "description": "Client-supplied, connection-scoped `processHandle` from `process/spawn`.",
     "type": "string"
   },
   "stderr": {
     "description": "Buffered stderr capture.\n\nEmpty when stderr was streamed via `process/outputDelta`.",
     "type": "string"
   },
   "stderrCapReached": {
     "description": "Whether stderr reached `outputBytesCap`.\n\nIn streaming mode, stderr is empty and cap state is also reported on the final stderr `process/outputDelta` notification.",
     "type": "boolean"
   },
   "stdout": {
     "description": "Buffered stdout capture.\n\nEmpty when stdout was streamed via `process/outputDelta`.",
     "type": "string"
   },
   "stdoutCapReached": {
     "description": "Whether stdout reached `outputBytesCap`.\n\nIn streaming mode, stdout is empty and cap state is also reported on the final stdout `process/outputDelta` notification.",
     "type": "boolean"
   }
 },
 "$schema": "http://json-schema.org/draft-07/schema#"
}

Fields

exit_code: i32

Process exit code.

process_handle: String

Client-supplied, connection-scoped processHandle from process/spawn.

stderr: String

Buffered stderr capture.

Empty when stderr was streamed via process/outputDelta.

stderr_cap_reached: bool

Whether stderr reached outputBytesCap.

In streaming mode, stderr is empty and cap state is also reported on the final stderr process/outputDelta notification.

stdout: String

Buffered stdout capture.

Empty when stdout was streamed via process/outputDelta.

stdout_cap_reached: bool

Whether stdout reached outputBytesCap.

In streaming mode, stdout is empty and cap state is also reported on the final stdout process/outputDelta notification.