pub struct ProcessOutputDeltaNotification {
pub cap_reached: bool,
pub delta_base64: String,
pub process_handle: String,
pub stream: ProcessOutputStream,
}Expand description
Base64-encoded output chunk emitted for a streaming process/spawn request.
JSON schema
{
"title": "ProcessOutputDeltaNotification",
"description": "Base64-encoded output chunk emitted for a streaming `process/spawn` request.",
"type": "object",
"required": [
"capReached",
"deltaBase64",
"processHandle",
"stream"
],
"properties": {
"capReached": {
"description": "True on the final streamed chunk for this stream when output was truncated by `outputBytesCap`.",
"type": "boolean"
},
"deltaBase64": {
"description": "Base64-encoded output bytes.",
"type": "string"
},
"processHandle": {
"description": "Client-supplied, connection-scoped `processHandle` from `process/spawn`.",
"type": "string"
},
"stream": {
"description": "Output stream this chunk belongs to.",
"allOf": [
{
"$ref": "#/definitions/ProcessOutputStream"
}
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cap_reached: boolTrue on the final streamed chunk for this stream when output was truncated by outputBytesCap.
delta_base64: StringBase64-encoded output bytes.
process_handle: StringClient-supplied, connection-scoped processHandle from process/spawn.
stream: ProcessOutputStreamOutput stream this chunk belongs to.