pub struct Resource {
pub annotations: Option<Value>,
pub description: Option<String>,
pub icons: Option<Vec<Value>>,
pub meta: Option<Value>,
pub mime_type: Option<String>,
pub name: String,
pub size: Option<i64>,
pub title: Option<String>,
pub uri: String,
}Expand description
A known resource that the server is capable of reading.
JSON schema
{
"description": "A known resource that the server is capable of reading.",
"type": "object",
"required": [
"name",
"uri"
],
"properties": {
"_meta": true,
"annotations": true,
"description": {
"type": [
"string",
"null"
]
},
"icons": {
"type": [
"array",
"null"
],
"items": true
},
"mimeType": {
"type": [
"string",
"null"
]
},
"name": {
"type": "string"
},
"size": {
"type": [
"integer",
"null"
],
"format": "int64"
},
"title": {
"type": [
"string",
"null"
]
},
"uri": {
"type": "string"
}
}
}Fields
annotations: Option<Value>description: Option<String>icons: Option<Vec<Value>>meta: Option<Value>mime_type: Option<String>name: Stringsize: Option<i64>title: Option<String>uri: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Resource
impl<'de> Deserialize<'de> for Resource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more