pub struct SelectedCapabilityRoot {
pub id: String,
pub location: CapabilityRootLocation,
}Expand description
A user-selected root that can expose one or more runtime capabilities.
JSON schema
{
"description": "A user-selected root that can expose one or more runtime capabilities.",
"type": "object",
"required": [
"id",
"location"
],
"properties": {
"id": {
"description": "Stable identifier supplied by the capability selection platform.",
"type": "string"
},
"location": {
"description": "Where the selected root can be resolved.",
"allOf": [
{
"$ref": "#/definitions/CapabilityRootLocation"
}
]
}
}
}Fields
id: StringStable identifier supplied by the capability selection platform.
location: CapabilityRootLocationWhere the selected root can be resolved.