pub struct SkillsListParams {
pub cwds: Vec<String>,
pub force_reload: Option<bool>,
}Expand description
SkillsListParams
JSON schema
{
"title": "SkillsListParams",
"type": "object",
"properties": {
"cwds": {
"description": "When empty, defaults to the current session working directory.",
"type": "array",
"items": {
"type": "string"
}
},
"forceReload": {
"description": "When true, bypass the skills cache and re-scan skills from disk.",
"type": "boolean"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cwds: Vec<String>When empty, defaults to the current session working directory.
force_reload: Option<bool>When true, bypass the skills cache and re-scan skills from disk.