ThreadBackgroundTerminalsListResponse

Struct ThreadBackgroundTerminalsListResponse 

pub struct ThreadBackgroundTerminalsListResponse {
    pub data: Vec<ThreadBackgroundTerminal>,
    pub next_cursor: Option<String>,
}
ThreadBackgroundTerminalsListResponse

JSON schema
{
 "title": "ThreadBackgroundTerminalsListResponse",
 "type": "object",
 "required": [
   "data"
 ],
 "properties": {
   "data": {
     "type": "array",
     "items": {
       "$ref": "#/definitions/ThreadBackgroundTerminal"
     }
   },
   "nextCursor": {
     "description": "Opaque cursor to pass to the next call to continue after the last item. If None, there are no more items to return.",
     "type": [
       "string",
       "null"
     ]
   }
 },
 "$schema": "http://json-schema.org/draft-07/schema#"
}

Fields

data: Vec<ThreadBackgroundTerminal>next_cursor: Option<String>

Opaque cursor to pass to the next call to continue after the last item. If None, there are no more items to return.