pub struct ThreadIncrementElicitationResponse {
pub count: i64,
pub paused: bool,
}Expand description
Response for thread/increment_elicitation.
JSON schema
{
"title": "ThreadIncrementElicitationResponse",
"description": "Response for `thread/increment_elicitation`.",
"type": "object",
"required": [
"count",
"paused"
],
"properties": {
"count": {
"description": "Current out-of-band elicitation count after the increment.",
"type": "integer",
"format": "int64"
},
"paused": {
"description": "Whether timeout accounting is paused after applying the increment.",
"type": "boolean"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
count: i64Current out-of-band elicitation count after the increment.
paused: boolWhether timeout accounting is paused after applying the increment.