pub struct ThreadItemsListParams {
pub cursor: Option<String>,
pub limit: Option<u32>,
pub sort_direction: Option<SortDirection>,
pub thread_id: String,
pub turn_id: Option<String>,
}Expand description
ThreadItemsListParams
JSON schema
{
"title": "ThreadItemsListParams",
"type": "object",
"required": [
"threadId"
],
"properties": {
"cursor": {
"description": "Opaque cursor to pass to the next call to continue after the last item.",
"type": [
"string",
"null"
]
},
"limit": {
"description": "Optional item page size.",
"type": [
"integer",
"null"
],
"format": "uint32",
"minimum": 0.0
},
"sortDirection": {
"description": "Optional item pagination direction; defaults to ascending.",
"anyOf": [
{
"$ref": "#/definitions/SortDirection"
},
{
"type": "null"
}
]
},
"threadId": {
"type": "string"
},
"turnId": {
"description": "Optional turn id to filter by. When omitted, returns items across the thread.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cursor: Option<String>Opaque cursor to pass to the next call to continue after the last item.
limit: Option<u32>Optional item page size.
sort_direction: Option<SortDirection>Optional item pagination direction; defaults to ascending.
thread_id: Stringturn_id: Option<String>Optional turn id to filter by. When omitted, returns items across the thread.