pub struct ThreadItemsListResponse {
pub backwards_cursor: Option<String>,
pub data: Vec<ThreadItem>,
pub next_cursor: Option<String>,
}Expand description
ThreadItemsListResponse
JSON schema
{
"title": "ThreadItemsListResponse",
"type": "object",
"required": [
"data"
],
"properties": {
"backwardsCursor": {
"description": "Opaque cursor to pass as `cursor` when reversing `sortDirection`. This is only populated when the page contains at least one item.",
"type": [
"string",
"null"
]
},
"data": {
"type": "array",
"items": {
"$ref": "#/definitions/ThreadItem"
}
},
"nextCursor": {
"description": "Opaque cursor to pass to the next call to continue after the last item. if None, there are no more items to return.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
backwards_cursor: Option<String>Opaque cursor to pass as cursor when reversing sortDirection. This is only populated when the page contains at least one item.
data: Vec<ThreadItem>next_cursor: Option<String>Opaque cursor to pass to the next call to continue after the last item. if None, there are no more items to return.