pub struct ThreadListParams {
pub ancestor_thread_id: Option<String>,
pub archived: Option<bool>,
pub cursor: Option<String>,
pub cwd: Option<ThreadListCwdFilter>,
pub limit: Option<u32>,
pub model_providers: Option<Vec<String>>,
pub parent_thread_id: Option<String>,
pub search_term: Option<String>,
pub sort_direction: Option<SortDirection>,
pub sort_key: Option<ThreadSortKey>,
pub source_kinds: Option<Vec<ThreadSourceKind>>,
pub use_state_db_only: Option<bool>,
}Expand description
ThreadListParams
JSON schema
{
"title": "ThreadListParams",
"type": "object",
"properties": {
"ancestorThreadId": {
"description": "Optional ancestor thread filter. Returns spawned descendants at any depth, excluding the ancestor itself. Mutually exclusive with `parentThreadId`.",
"type": [
"string",
"null"
]
},
"archived": {
"description": "Optional archived filter; when set to true, only archived threads are returned. If false or null, only non-archived threads are returned.",
"type": [
"boolean",
"null"
]
},
"cursor": {
"description": "Opaque pagination cursor returned by a previous call.",
"type": [
"string",
"null"
]
},
"cwd": {
"description": "Optional cwd filter or filters; when set, only threads whose session cwd exactly matches one of these paths are returned.",
"anyOf": [
{
"$ref": "#/definitions/ThreadListCwdFilter"
},
{
"type": "null"
}
]
},
"limit": {
"description": "Optional page size; defaults to a reasonable server-side value.",
"type": [
"integer",
"null"
],
"format": "uint32",
"minimum": 0.0
},
"modelProviders": {
"description": "Optional provider filter; when set, only sessions recorded under these providers are returned. When present but empty, includes all providers.",
"type": [
"array",
"null"
],
"items": {
"type": "string"
}
},
"parentThreadId": {
"description": "Optional direct parent thread filter. Mutually exclusive with `ancestorThreadId`.",
"type": [
"string",
"null"
]
},
"searchTerm": {
"description": "Optional substring filter for the extracted thread title.",
"type": [
"string",
"null"
]
},
"sortDirection": {
"description": "Optional sort direction; defaults to descending (newest first).",
"anyOf": [
{
"$ref": "#/definitions/SortDirection"
},
{
"type": "null"
}
]
},
"sortKey": {
"description": "Optional sort key; defaults to created_at.",
"anyOf": [
{
"$ref": "#/definitions/ThreadSortKey"
},
{
"type": "null"
}
]
},
"sourceKinds": {
"description": "Optional source filter; when set, only sessions from these source kinds are returned. When omitted or empty, defaults to interactive sources.",
"type": [
"array",
"null"
],
"items": {
"$ref": "#/definitions/ThreadSourceKind"
}
},
"useStateDbOnly": {
"description": "If true, return from the state DB without scanning JSONL rollouts to repair thread metadata. Omitted or false preserves scan-and-repair behavior.",
"type": "boolean"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
ancestor_thread_id: Option<String>Optional ancestor thread filter. Returns spawned descendants at any depth, excluding the ancestor itself. Mutually exclusive with parentThreadId.
archived: Option<bool>Optional archived filter; when set to true, only archived threads are returned. If false or null, only non-archived threads are returned.
cursor: Option<String>Opaque pagination cursor returned by a previous call.
cwd: Option<ThreadListCwdFilter>Optional cwd filter or filters; when set, only threads whose session cwd exactly matches one of these paths are returned.
limit: Option<u32>Optional page size; defaults to a reasonable server-side value.
model_providers: Option<Vec<String>>Optional provider filter; when set, only sessions recorded under these providers are returned. When present but empty, includes all providers.
parent_thread_id: Option<String>Optional direct parent thread filter. Mutually exclusive with ancestorThreadId.
search_term: Option<String>Optional substring filter for the extracted thread title.
sort_direction: Option<SortDirection>Optional sort direction; defaults to descending (newest first).
sort_key: Option<ThreadSortKey>Optional sort key; defaults to created_at.
source_kinds: Option<Vec<ThreadSourceKind>>Optional source filter; when set, only sessions from these source kinds are returned. When omitted or empty, defaults to interactive sources.
use_state_db_only: Option<bool>If true, return from the state DB without scanning JSONL rollouts to repair thread metadata. Omitted or false preserves scan-and-repair behavior.