pub struct ThreadListResponse {
pub backwards_cursor: Option<String>,
pub data: Vec<Thread>,
pub next_cursor: Option<String>,
}Expand description
ThreadListResponse
JSON schema
{
"title": "ThreadListResponse",
"type": "object",
"required": [
"data"
],
"properties": {
"backwardsCursor": {
"description": "Opaque cursor to pass as `cursor` when reversing `sortDirection`. This is only populated when the page contains at least one thread. Use it with the opposite `sortDirection`; for timestamp sorts it anchors at the start of the page timestamp so same-second updates are not skipped.",
"type": [
"string",
"null"
]
},
"data": {
"type": "array",
"items": {
"$ref": "#/definitions/Thread"
}
},
"nextCursor": {
"description": "Opaque cursor to pass to the next call to continue after the last item. if None, there are no more items to return.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
backwards_cursor: Option<String>Opaque cursor to pass as cursor when reversing sortDirection. This is only populated when the page contains at least one thread. Use it with the opposite sortDirection; for timestamp sorts it anchors at the start of the page timestamp so same-second updates are not skipped.
data: Vec<Thread>next_cursor: Option<String>Opaque cursor to pass to the next call to continue after the last item. if None, there are no more items to return.