pub struct ThreadLoadedListResponse {
pub data: Vec<String>,
pub next_cursor: Option<String>,
}Expand description
ThreadLoadedListResponse
JSON schema
{
"title": "ThreadLoadedListResponse",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"description": "Thread ids for sessions currently loaded in memory.",
"type": "array",
"items": {
"type": "string"
}
},
"nextCursor": {
"description": "Opaque cursor to pass to the next call to continue after the last item. if None, there are no more items to return.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
data: Vec<String>Thread ids for sessions currently loaded in memory.
next_cursor: Option<String>Opaque cursor to pass to the next call to continue after the last item. if None, there are no more items to return.