pub struct ThreadMetadataGitInfoUpdateParams {
pub branch: Option<String>,
pub origin_url: Option<String>,
pub sha: Option<String>,
}Expand description
ThreadMetadataGitInfoUpdateParams
JSON schema
{
"type": "object",
"properties": {
"branch": {
"description": "Omit to leave the stored branch unchanged, set to `null` to clear it, or provide a non-empty string to replace it.",
"type": [
"string",
"null"
]
},
"originUrl": {
"description": "Omit to leave the stored origin URL unchanged, set to `null` to clear it, or provide a non-empty string to replace it.",
"type": [
"string",
"null"
]
},
"sha": {
"description": "Omit to leave the stored commit unchanged, set to `null` to clear it, or provide a non-empty string to replace it.",
"type": [
"string",
"null"
]
}
}
}Fields
branch: Option<String>Omit to leave the stored branch unchanged, set to null to clear it, or provide a non-empty string to replace it.
origin_url: Option<String>Omit to leave the stored origin URL unchanged, set to null to clear it, or provide a non-empty string to replace it.
sha: Option<String>Omit to leave the stored commit unchanged, set to null to clear it, or provide a non-empty string to replace it.