pub struct ThreadMetadataUpdateParams {
pub git_info: Option<ThreadMetadataGitInfoUpdateParams>,
pub thread_id: String,
}Expand description
ThreadMetadataUpdateParams
JSON schema
{
"title": "ThreadMetadataUpdateParams",
"type": "object",
"required": [
"threadId"
],
"properties": {
"gitInfo": {
"description": "Patch the stored Git metadata for this thread. Omit a field to leave it unchanged, set it to `null` to clear it, or provide a string to replace the stored value.",
"anyOf": [
{
"$ref": "#/definitions/ThreadMetadataGitInfoUpdateParams"
},
{
"type": "null"
}
]
},
"threadId": {
"type": "string"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
git_info: Option<ThreadMetadataGitInfoUpdateParams>Patch the stored Git metadata for this thread. Omit a field to leave it unchanged, set it to null to clear it, or provide a string to replace the stored value.
thread_id: StringTrait Implementations
Sourceimpl Clone for ThreadMetadataUpdateParams
impl Clone for ThreadMetadataUpdateParams
Sourcefn clone(&self) -> ThreadMetadataUpdateParams
fn clone(&self) -> ThreadMetadataUpdateParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadMetadataUpdateParams
impl Debug for ThreadMetadataUpdateParams
Sourceimpl<'de> Deserialize<'de> for ThreadMetadataUpdateParams
impl<'de> Deserialize<'de> for ThreadMetadataUpdateParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more