pub struct ThreadRealtimeTranscriptDoneNotification {
pub role: String,
pub text: String,
pub thread_id: String,
}Expand description
EXPERIMENTAL - final transcript text emitted when realtime completes a transcript part.
JSON schema
{
"title": "ThreadRealtimeTranscriptDoneNotification",
"description": "EXPERIMENTAL - final transcript text emitted when realtime completes a transcript part.",
"type": "object",
"required": [
"role",
"text",
"threadId"
],
"properties": {
"role": {
"type": "string"
},
"text": {
"description": "Final complete text for the transcript part.",
"type": "string"
},
"threadId": {
"type": "string"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
role: Stringtext: StringFinal complete text for the transcript part.
thread_id: StringTrait Implementations
Sourceimpl Clone for ThreadRealtimeTranscriptDoneNotification
impl Clone for ThreadRealtimeTranscriptDoneNotification
Sourcefn clone(&self) -> ThreadRealtimeTranscriptDoneNotification
fn clone(&self) -> ThreadRealtimeTranscriptDoneNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ThreadRealtimeTranscriptDoneNotification
impl<'de> Deserialize<'de> for ThreadRealtimeTranscriptDoneNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ThreadRealtimeTranscriptDoneNotification> for ServerNotification
impl From<ThreadRealtimeTranscriptDoneNotification> for ServerNotification
Sourcefn from(value: ThreadRealtimeTranscriptDoneNotification) -> Self
fn from(value: ThreadRealtimeTranscriptDoneNotification) -> Self
Converts to this type from the input type.