pub struct ThreadResumeInitialTurnsPageParams {
pub items_view: Option<TurnItemsView>,
pub limit: Option<u32>,
pub sort_direction: Option<SortDirection>,
}Expand description
ThreadResumeInitialTurnsPageParams
JSON schema
{
"type": "object",
"properties": {
"itemsView": {
"description": "How much item detail to include for each returned turn; defaults to summary.",
"anyOf": [
{
"$ref": "#/definitions/TurnItemsView"
},
{
"type": "null"
}
]
},
"limit": {
"description": "Optional turn page size.",
"type": [
"integer",
"null"
],
"format": "uint32",
"minimum": 0.0
},
"sortDirection": {
"description": "Optional turn pagination direction; defaults to descending.",
"anyOf": [
{
"$ref": "#/definitions/SortDirection"
},
{
"type": "null"
}
]
}
}
}Fields
items_view: Option<TurnItemsView>How much item detail to include for each returned turn; defaults to summary.
limit: Option<u32>Optional turn page size.
sort_direction: Option<SortDirection>Optional turn pagination direction; defaults to descending.