pub struct ThreadResumeResponse {Show 14 fields
pub active_permission_profile: Option<ActivePermissionProfile>,
pub approval_policy: AskForApproval,
pub approvals_reviewer: ApprovalsReviewer,
pub cwd: AbsolutePathBuf,
pub initial_turns_page: Option<TurnsPage>,
pub instruction_sources: Vec<LegacyAppPathString>,
pub model: String,
pub model_provider: String,
pub multi_agent_mode: MultiAgentMode,
pub reasoning_effort: Option<ReasoningEffort>,
pub runtime_workspace_roots: Vec<AbsolutePathBuf>,
pub sandbox: SandboxPolicy,
pub service_tier: Option<String>,
pub thread: Thread,
}Expand description
ThreadResumeResponse
JSON schema
{
"title": "ThreadResumeResponse",
"type": "object",
"required": [
"approvalPolicy",
"approvalsReviewer",
"cwd",
"model",
"modelProvider",
"sandbox",
"thread"
],
"properties": {
"activePermissionProfile": {
"description": "Named or implicit built-in profile that produced the active permissions, when known.",
"default": null,
"anyOf": [
{
"$ref": "#/definitions/ActivePermissionProfile"
},
{
"type": "null"
}
]
},
"approvalPolicy": {
"$ref": "#/definitions/AskForApproval"
},
"approvalsReviewer": {
"description": "Reviewer currently used for approval requests on this thread.",
"allOf": [
{
"$ref": "#/definitions/ApprovalsReviewer"
}
]
},
"cwd": {
"$ref": "#/definitions/AbsolutePathBuf"
},
"initialTurnsPage": {
"description": "`thread/turns/list` page returned when requested by `initialTurnsPage`.",
"default": null,
"anyOf": [
{
"$ref": "#/definitions/TurnsPage"
},
{
"type": "null"
}
]
},
"instructionSources": {
"description": "Environment-native paths to instruction source files currently loaded for this thread.",
"default": [],
"type": "array",
"items": {
"$ref": "#/definitions/LegacyAppPathString"
}
},
"model": {
"type": "string"
},
"modelProvider": {
"type": "string"
},
"multiAgentMode": {
"description": "@deprecated Always `explicitRequestOnly`. Use `reasoningEffort` for Ultra behavior.",
"default": "explicitRequestOnly",
"allOf": [
{
"$ref": "#/definitions/MultiAgentMode"
}
]
},
"reasoningEffort": {
"anyOf": [
{
"$ref": "#/definitions/ReasoningEffort"
},
{
"type": "null"
}
]
},
"runtimeWorkspaceRoots": {
"description": "Thread-scoped runtime workspace roots used to materialize `:workspace_roots`.",
"default": [],
"type": "array",
"items": {
"$ref": "#/definitions/AbsolutePathBuf"
}
},
"sandbox": {
"description": "Legacy sandbox policy retained for compatibility. Experimental clients should prefer `activePermissionProfile` for profile provenance.",
"allOf": [
{
"$ref": "#/definitions/SandboxPolicy"
}
]
},
"serviceTier": {
"type": [
"string",
"null"
]
},
"thread": {
"$ref": "#/definitions/Thread"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
active_permission_profile: Option<ActivePermissionProfile>Named or implicit built-in profile that produced the active permissions, when known.
approval_policy: AskForApprovalapprovals_reviewer: ApprovalsReviewerReviewer currently used for approval requests on this thread.
cwd: AbsolutePathBufinitial_turns_page: Option<TurnsPage>thread/turns/list page returned when requested by initialTurnsPage.
instruction_sources: Vec<LegacyAppPathString>Environment-native paths to instruction source files currently loaded for this thread.
model: Stringmodel_provider: Stringmulti_agent_mode: MultiAgentMode@deprecated Always explicitRequestOnly. Use reasoningEffort for Ultra behavior.
reasoning_effort: Option<ReasoningEffort>runtime_workspace_roots: Vec<AbsolutePathBuf>Thread-scoped runtime workspace roots used to materialize :workspace_roots.
sandbox: SandboxPolicyLegacy sandbox policy retained for compatibility. Experimental clients should prefer activePermissionProfile for profile provenance.
service_tier: Option<String>thread: ThreadTrait Implementations
Sourceimpl Clone for ThreadResumeResponse
impl Clone for ThreadResumeResponse
Sourcefn clone(&self) -> ThreadResumeResponse
fn clone(&self) -> ThreadResumeResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadResumeResponse
impl Debug for ThreadResumeResponse
Sourceimpl<'de> Deserialize<'de> for ThreadResumeResponse
impl<'de> Deserialize<'de> for ThreadResumeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more