pub struct ThreadRollbackResponse {
pub thread: Thread,
}Expand description
ThreadRollbackResponse
JSON schema
{
"title": "ThreadRollbackResponse",
"type": "object",
"required": [
"thread"
],
"properties": {
"thread": {
"description": "The updated thread after applying the rollback, with `turns` populated.\n\nThe ThreadItems stored in each Turn are lossy since we explicitly do not persist all agent interactions, such as command executions. This is the same behavior as `thread/resume`.",
"allOf": [
{
"$ref": "#/definitions/Thread"
}
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
thread: ThreadThe updated thread after applying the rollback, with turns populated.
The ThreadItems stored in each Turn are lossy since we explicitly do not persist all agent interactions, such as command executions. This is the same behavior as thread/resume.