pub struct ThreadTurnsListParams {
pub cursor: Option<String>,
pub items_view: Option<TurnItemsView>,
pub limit: Option<u32>,
pub sort_direction: Option<SortDirection>,
pub thread_id: String,
}Expand description
ThreadTurnsListParams
JSON schema
{
"title": "ThreadTurnsListParams",
"type": "object",
"required": [
"threadId"
],
"properties": {
"cursor": {
"description": "Opaque cursor to pass to the next call to continue after the last turn.",
"type": [
"string",
"null"
]
},
"itemsView": {
"description": "How much item detail to include for each returned turn; defaults to summary.",
"anyOf": [
{
"$ref": "#/definitions/TurnItemsView"
},
{
"type": "null"
}
]
},
"limit": {
"description": "Optional turn page size.",
"type": [
"integer",
"null"
],
"format": "uint32",
"minimum": 0.0
},
"sortDirection": {
"description": "Optional turn pagination direction; defaults to descending.",
"anyOf": [
{
"$ref": "#/definitions/SortDirection"
},
{
"type": "null"
}
]
},
"threadId": {
"type": "string"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
cursor: Option<String>Opaque cursor to pass to the next call to continue after the last turn.
items_view: Option<TurnItemsView>How much item detail to include for each returned turn; defaults to summary.
limit: Option<u32>Optional turn page size.
sort_direction: Option<SortDirection>Optional turn pagination direction; defaults to descending.
thread_id: StringTrait Implementations
Sourceimpl Clone for ThreadTurnsListParams
impl Clone for ThreadTurnsListParams
Sourcefn clone(&self) -> ThreadTurnsListParams
fn clone(&self) -> ThreadTurnsListParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadTurnsListParams
impl Debug for ThreadTurnsListParams
Sourceimpl<'de> Deserialize<'de> for ThreadTurnsListParams
impl<'de> Deserialize<'de> for ThreadTurnsListParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more