pub struct ThreadTurnsListResponse {
pub backwards_cursor: Option<String>,
pub data: Vec<Turn>,
pub next_cursor: Option<String>,
}Expand description
ThreadTurnsListResponse
JSON schema
{
"title": "ThreadTurnsListResponse",
"type": "object",
"required": [
"data"
],
"properties": {
"backwardsCursor": {
"description": "Opaque cursor to pass as `cursor` when reversing `sortDirection`. This is only populated when the page contains at least one turn. Use it with the opposite `sortDirection` to include the anchor turn again and catch updates to that turn.",
"type": [
"string",
"null"
]
},
"data": {
"type": "array",
"items": {
"$ref": "#/definitions/Turn"
}
},
"nextCursor": {
"description": "Opaque cursor to pass to the next call to continue after the last turn. if None, there are no more turns to return.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
backwards_cursor: Option<String>Opaque cursor to pass as cursor when reversing sortDirection. This is only populated when the page contains at least one turn. Use it with the opposite sortDirection to include the anchor turn again and catch updates to that turn.
data: Vec<Turn>next_cursor: Option<String>Opaque cursor to pass to the next call to continue after the last turn. if None, there are no more turns to return.