pub struct TurnDiffUpdatedNotification {
pub diff: String,
pub thread_id: String,
pub turn_id: String,
}Expand description
Notification that the turn-level unified diff has changed. Contains the latest aggregated diff across all file changes in the turn.
JSON schema
{
"title": "TurnDiffUpdatedNotification",
"description": "Notification that the turn-level unified diff has changed. Contains the latest aggregated diff across all file changes in the turn.",
"type": "object",
"required": [
"diff",
"threadId",
"turnId"
],
"properties": {
"diff": {
"type": "string"
},
"threadId": {
"type": "string"
},
"turnId": {
"type": "string"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
diff: Stringthread_id: Stringturn_id: StringTrait Implementations
Sourceimpl Clone for TurnDiffUpdatedNotification
impl Clone for TurnDiffUpdatedNotification
Sourcefn clone(&self) -> TurnDiffUpdatedNotification
fn clone(&self) -> TurnDiffUpdatedNotification
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TurnDiffUpdatedNotification
impl Debug for TurnDiffUpdatedNotification
Sourceimpl<'de> Deserialize<'de> for TurnDiffUpdatedNotification
impl<'de> Deserialize<'de> for TurnDiffUpdatedNotification
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TurnDiffUpdatedNotification> for ServerNotification
impl From<TurnDiffUpdatedNotification> for ServerNotification
Sourcefn from(value: TurnDiffUpdatedNotification) -> Self
fn from(value: TurnDiffUpdatedNotification) -> Self
Converts to this type from the input type.