TurnSteerParams

Struct TurnSteerParams 

pub struct TurnSteerParams {
    pub additional_context: Option<HashMap<String, AdditionalContextEntry>>,
    pub client_user_message_id: Option<String>,
    pub expected_turn_id: String,
    pub input: Vec<UserInput>,
    pub responsesapi_client_metadata: Option<HashMap<String, String>>,
    pub thread_id: String,
}
TurnSteerParams

JSON schema
{
 "title": "TurnSteerParams",
 "type": "object",
 "required": [
   "expectedTurnId",
   "input",
   "threadId"
 ],
 "properties": {
   "additionalContext": {
     "description": "Optional client-provided context fragments keyed by an opaque source identifier.",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": {
       "$ref": "#/definitions/AdditionalContextEntry"
     }
   },
   "clientUserMessageId": {
     "type": [
       "string",
       "null"
     ]
   },
   "expectedTurnId": {
     "description": "Required active turn id precondition. The request fails when it does not match the currently active turn.",
     "type": "string"
   },
   "input": {
     "type": "array",
     "items": {
       "$ref": "#/definitions/UserInput"
     }
   },
   "responsesapiClientMetadata": {
     "description": "Optional metadata to enrich Codex's ResponsesAPI turn metadata.\n\nEntries are flattened into the JSON string sent as `client_metadata[\"x-codex-turn-metadata\"]` on ResponsesAPI HTTP and websocket requests.\n\nThey are not sent as top-level ResponsesAPI `client_metadata` keys, and reserved keys such as `session_id`, `thread_id`, `turn_id`, and `window_id` cannot be overridden.",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": {
       "type": "string"
     }
   },
   "threadId": {
     "type": "string"
   }
 },
 "$schema": "http://json-schema.org/draft-07/schema#"
}

Fields

additional_context: Option<HashMap<String, AdditionalContextEntry>>

Optional client-provided context fragments keyed by an opaque source identifier.

client_user_message_id: Option<String>expected_turn_id: String

Required active turn id precondition. The request fails when it does not match the currently active turn.

input: Vec<UserInput>responsesapi_client_metadata: Option<HashMap<String, String>>

Optional metadata to enrich Codex’s ResponsesAPI turn metadata.

Entries are flattened into the JSON string sent as client_metadata["x-codex-turn-metadata"] on ResponsesAPI HTTP and websocket requests.

They are not sent as top-level ResponsesAPI client_metadata keys, and reserved keys such as session_id, thread_id, turn_id, and window_id cannot be overridden.

thread_id: String