pub struct WarningNotification {
pub message: String,
pub thread_id: Option<String>,
}Expand description
WarningNotification
JSON schema
{
"title": "WarningNotification",
"type": "object",
"required": [
"message"
],
"properties": {
"message": {
"description": "Concise warning message for the user.",
"type": "string"
},
"threadId": {
"description": "Optional thread target when the warning applies to a specific thread.",
"type": [
"string",
"null"
]
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
message: StringConcise warning message for the user.
thread_id: Option<String>Optional thread target when the warning applies to a specific thread.