pub enum McpServerElicitationRequestParams {
Form {
message: String,
meta: Option<Value>,
requested_schema: McpElicitationSchema,
server_name: String,
thread_id: String,
turn_id: Option<String>,
},
OpenaiForm {
message: String,
meta: Option<Value>,
requested_schema: Value,
server_name: String,
thread_id: String,
turn_id: Option<String>,
},
Url {
elicitation_id: String,
message: String,
meta: Option<Value>,
server_name: String,
thread_id: String,
turn_id: Option<String>,
url: String,
},
}Expand description
McpServerElicitationRequestParams
JSON schema
{
"title": "McpServerElicitationRequestParams",
"oneOf": [
{
"type": "object",
"required": [
"message",
"mode",
"requestedSchema",
"serverName",
"threadId"
],
"properties": {
"serverName": {
"type": "string"
},
"threadId": {
"type": "string"
},
"turnId": {
"description": "Active Codex turn when this elicitation was observed, if app-server could correlate one.\n\nThis is nullable because MCP models elicitation as a standalone server-to-client request identified by the MCP server request id. It may be triggered during a turn, but turn context is app-server correlation rather than part of the protocol identity of the elicitation itself.",
"type": [
"string",
"null"
]
},
"_meta": true,
"message": {
"type": "string"
},
"mode": {
"type": "string",
"enum": [
"form"
]
},
"requestedSchema": {
"$ref": "#/definitions/McpElicitationSchema"
}
}
},
{
"type": "object",
"required": [
"message",
"mode",
"requestedSchema",
"serverName",
"threadId"
],
"properties": {
"serverName": {
"type": "string"
},
"threadId": {
"type": "string"
},
"turnId": {
"description": "Active Codex turn when this elicitation was observed, if app-server could correlate one.\n\nThis is nullable because MCP models elicitation as a standalone server-to-client request identified by the MCP server request id. It may be triggered during a turn, but turn context is app-server correlation rather than part of the protocol identity of the elicitation itself.",
"type": [
"string",
"null"
]
},
"_meta": true,
"message": {
"type": "string"
},
"mode": {
"type": "string",
"enum": [
"openai/form"
]
},
"requestedSchema": true
}
},
{
"type": "object",
"required": [
"elicitationId",
"message",
"mode",
"serverName",
"threadId",
"url"
],
"properties": {
"serverName": {
"type": "string"
},
"threadId": {
"type": "string"
},
"turnId": {
"description": "Active Codex turn when this elicitation was observed, if app-server could correlate one.\n\nThis is nullable because MCP models elicitation as a standalone server-to-client request identified by the MCP server request id. It may be triggered during a turn, but turn context is app-server correlation rather than part of the protocol identity of the elicitation itself.",
"type": [
"string",
"null"
]
},
"_meta": true,
"elicitationId": {
"type": "string"
},
"message": {
"type": "string"
},
"mode": {
"type": "string",
"enum": [
"url"
]
},
"url": {
"type": "string"
}
}
}
]
}Variants
Form
Fields
requested_schema: McpElicitationSchematurn_id: Option<String>Active Codex turn when this elicitation was observed, if app-server could correlate one.
This is nullable because MCP models elicitation as a standalone server-to-client request identified by the MCP server request id. It may be triggered during a turn, but turn context is app-server correlation rather than part of the protocol identity of the elicitation itself.
OpenaiForm
Fields
turn_id: Option<String>Active Codex turn when this elicitation was observed, if app-server could correlate one.
This is nullable because MCP models elicitation as a standalone server-to-client request identified by the MCP server request id. It may be triggered during a turn, but turn context is app-server correlation rather than part of the protocol identity of the elicitation itself.
Url
Fields
turn_id: Option<String>Active Codex turn when this elicitation was observed, if app-server could correlate one.
This is nullable because MCP models elicitation as a standalone server-to-client request identified by the MCP server request id. It may be triggered during a turn, but turn context is app-server correlation rather than part of the protocol identity of the elicitation itself.