pub enum ServerNotification {
Show 68 variants
Error(ErrorNotification),
ThreadStarted(ThreadStartedNotification),
ThreadStatusChanged(ThreadStatusChangedNotification),
ThreadArchived(ThreadArchivedNotification),
ThreadDeleted(ThreadDeletedNotification),
ThreadUnarchived(ThreadUnarchivedNotification),
ThreadClosed(ThreadClosedNotification),
SkillsChanged(SkillsChangedNotification),
ThreadNameUpdated(ThreadNameUpdatedNotification),
ThreadGoalUpdated(ThreadGoalUpdatedNotification),
ThreadGoalCleared(ThreadGoalClearedNotification),
ThreadSettingsUpdated(ThreadSettingsUpdatedNotification),
ThreadTokenUsageUpdated(ThreadTokenUsageUpdatedNotification),
TurnStarted(TurnStartedNotification),
HookStarted(HookStartedNotification),
TurnCompleted(TurnCompletedNotification),
HookCompleted(HookCompletedNotification),
TurnDiffUpdated(TurnDiffUpdatedNotification),
TurnPlanUpdated(TurnPlanUpdatedNotification),
ItemStarted(ItemStartedNotification),
ItemAutoApprovalReviewStarted(ItemGuardianApprovalReviewStartedNotification),
ItemAutoApprovalReviewCompleted(ItemGuardianApprovalReviewCompletedNotification),
ItemCompleted(ItemCompletedNotification),
ItemAgentMessageDelta(AgentMessageDeltaNotification),
ItemPlanDelta(PlanDeltaNotification),
CommandExecOutputDelta(CommandExecOutputDeltaNotification),
ProcessOutputDelta(ProcessOutputDeltaNotification),
ProcessExited(ProcessExitedNotification),
ItemCommandExecutionOutputDelta(CommandExecutionOutputDeltaNotification),
ItemCommandExecutionTerminalInteraction(TerminalInteractionNotification),
ItemFileChangeOutputDelta(FileChangeOutputDeltaNotification),
ItemFileChangePatchUpdated(FileChangePatchUpdatedNotification),
ServerRequestResolved(ServerRequestResolvedNotification),
ItemMcpToolCallProgress(McpToolCallProgressNotification),
McpServerOauthLoginCompleted(McpServerOauthLoginCompletedNotification),
McpServerStartupStatusUpdated(McpServerStatusUpdatedNotification),
AccountUpdated(AccountUpdatedNotification),
AccountRateLimitsUpdated(AccountRateLimitsUpdatedNotification),
AppListUpdated(AppListUpdatedNotification),
RemoteControlStatusChanged(RemoteControlStatusChangedNotification),
ExternalAgentConfigImportProgress(ExternalAgentConfigImportProgressNotification),
ExternalAgentConfigImportCompleted(ExternalAgentConfigImportCompletedNotification),
FsChanged(FsChangedNotification),
ItemReasoningSummaryTextDelta(ReasoningSummaryTextDeltaNotification),
ItemReasoningSummaryPartAdded(ReasoningSummaryPartAddedNotification),
ItemReasoningTextDelta(ReasoningTextDeltaNotification),
ThreadCompacted(ContextCompactedNotification),
ModelRerouted(ModelReroutedNotification),
ModelVerification(ModelVerificationNotification),
TurnModerationMetadata(TurnModerationMetadataNotification),
ModelSafetyBufferingUpdated(ModelSafetyBufferingUpdatedNotification),
Warning(WarningNotification),
GuardianWarning(GuardianWarningNotification),
DeprecationNotice(DeprecationNoticeNotification),
ConfigWarning(ConfigWarningNotification),
FuzzyFileSearchSessionUpdated(FuzzyFileSearchSessionUpdatedNotification),
FuzzyFileSearchSessionCompleted(FuzzyFileSearchSessionCompletedNotification),
ThreadRealtimeStarted(ThreadRealtimeStartedNotification),
ThreadRealtimeItemAdded(ThreadRealtimeItemAddedNotification),
ThreadRealtimeTranscriptDelta(ThreadRealtimeTranscriptDeltaNotification),
ThreadRealtimeTranscriptDone(ThreadRealtimeTranscriptDoneNotification),
ThreadRealtimeOutputAudioDelta(ThreadRealtimeOutputAudioDeltaNotification),
ThreadRealtimeSdp(ThreadRealtimeSdpNotification),
ThreadRealtimeError(ThreadRealtimeErrorNotification),
ThreadRealtimeClosed(ThreadRealtimeClosedNotification),
WindowsWorldWritableWarning(WindowsWorldWritableWarningNotification),
WindowsSandboxSetupCompleted(WindowsSandboxSetupCompletedNotification),
AccountLoginCompleted(AccountLoginCompletedNotification),
}Expand description
Notification sent from the server to the client.
JSON schema
{
"title": "ServerNotification",
"description": "Notification sent from the server to the client.",
"oneOf": [
{
"title": "ErrorNotification",
"description": "NEW NOTIFICATIONS",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "ErrorNotificationMethod",
"type": "string",
"enum": [
"error"
]
},
"params": {
"$ref": "#/definitions/ErrorNotification"
}
}
},
{
"title": "Thread/startedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/startedNotificationMethod",
"type": "string",
"enum": [
"thread/started"
]
},
"params": {
"$ref": "#/definitions/ThreadStartedNotification"
}
}
},
{
"title": "Thread/status/changedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/status/changedNotificationMethod",
"type": "string",
"enum": [
"thread/status/changed"
]
},
"params": {
"$ref": "#/definitions/ThreadStatusChangedNotification"
}
}
},
{
"title": "Thread/archivedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/archivedNotificationMethod",
"type": "string",
"enum": [
"thread/archived"
]
},
"params": {
"$ref": "#/definitions/ThreadArchivedNotification"
}
}
},
{
"title": "Thread/deletedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/deletedNotificationMethod",
"type": "string",
"enum": [
"thread/deleted"
]
},
"params": {
"$ref": "#/definitions/ThreadDeletedNotification"
}
}
},
{
"title": "Thread/unarchivedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/unarchivedNotificationMethod",
"type": "string",
"enum": [
"thread/unarchived"
]
},
"params": {
"$ref": "#/definitions/ThreadUnarchivedNotification"
}
}
},
{
"title": "Thread/closedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/closedNotificationMethod",
"type": "string",
"enum": [
"thread/closed"
]
},
"params": {
"$ref": "#/definitions/ThreadClosedNotification"
}
}
},
{
"title": "Skills/changedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Skills/changedNotificationMethod",
"type": "string",
"enum": [
"skills/changed"
]
},
"params": {
"$ref": "#/definitions/SkillsChangedNotification"
}
}
},
{
"title": "Thread/name/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/name/updatedNotificationMethod",
"type": "string",
"enum": [
"thread/name/updated"
]
},
"params": {
"$ref": "#/definitions/ThreadNameUpdatedNotification"
}
}
},
{
"title": "Thread/goal/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/goal/updatedNotificationMethod",
"type": "string",
"enum": [
"thread/goal/updated"
]
},
"params": {
"$ref": "#/definitions/ThreadGoalUpdatedNotification"
}
}
},
{
"title": "Thread/goal/clearedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/goal/clearedNotificationMethod",
"type": "string",
"enum": [
"thread/goal/cleared"
]
},
"params": {
"$ref": "#/definitions/ThreadGoalClearedNotification"
}
}
},
{
"title": "Thread/settings/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/settings/updatedNotificationMethod",
"type": "string",
"enum": [
"thread/settings/updated"
]
},
"params": {
"$ref": "#/definitions/ThreadSettingsUpdatedNotification"
}
}
},
{
"title": "Thread/tokenUsage/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/tokenUsage/updatedNotificationMethod",
"type": "string",
"enum": [
"thread/tokenUsage/updated"
]
},
"params": {
"$ref": "#/definitions/ThreadTokenUsageUpdatedNotification"
}
}
},
{
"title": "Turn/startedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Turn/startedNotificationMethod",
"type": "string",
"enum": [
"turn/started"
]
},
"params": {
"$ref": "#/definitions/TurnStartedNotification"
}
}
},
{
"title": "Hook/startedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Hook/startedNotificationMethod",
"type": "string",
"enum": [
"hook/started"
]
},
"params": {
"$ref": "#/definitions/HookStartedNotification"
}
}
},
{
"title": "Turn/completedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Turn/completedNotificationMethod",
"type": "string",
"enum": [
"turn/completed"
]
},
"params": {
"$ref": "#/definitions/TurnCompletedNotification"
}
}
},
{
"title": "Hook/completedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Hook/completedNotificationMethod",
"type": "string",
"enum": [
"hook/completed"
]
},
"params": {
"$ref": "#/definitions/HookCompletedNotification"
}
}
},
{
"title": "Turn/diff/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Turn/diff/updatedNotificationMethod",
"type": "string",
"enum": [
"turn/diff/updated"
]
},
"params": {
"$ref": "#/definitions/TurnDiffUpdatedNotification"
}
}
},
{
"title": "Turn/plan/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Turn/plan/updatedNotificationMethod",
"type": "string",
"enum": [
"turn/plan/updated"
]
},
"params": {
"$ref": "#/definitions/TurnPlanUpdatedNotification"
}
}
},
{
"title": "Item/startedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/startedNotificationMethod",
"type": "string",
"enum": [
"item/started"
]
},
"params": {
"$ref": "#/definitions/ItemStartedNotification"
}
}
},
{
"title": "Item/autoApprovalReview/startedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/autoApprovalReview/startedNotificationMethod",
"type": "string",
"enum": [
"item/autoApprovalReview/started"
]
},
"params": {
"$ref": "#/definitions/ItemGuardianApprovalReviewStartedNotification"
}
}
},
{
"title": "Item/autoApprovalReview/completedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/autoApprovalReview/completedNotificationMethod",
"type": "string",
"enum": [
"item/autoApprovalReview/completed"
]
},
"params": {
"$ref": "#/definitions/ItemGuardianApprovalReviewCompletedNotification"
}
}
},
{
"title": "Item/completedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/completedNotificationMethod",
"type": "string",
"enum": [
"item/completed"
]
},
"params": {
"$ref": "#/definitions/ItemCompletedNotification"
}
}
},
{
"title": "Item/agentMessage/deltaNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/agentMessage/deltaNotificationMethod",
"type": "string",
"enum": [
"item/agentMessage/delta"
]
},
"params": {
"$ref": "#/definitions/AgentMessageDeltaNotification"
}
}
},
{
"title": "Item/plan/deltaNotification",
"description": "EXPERIMENTAL - proposed plan streaming deltas for plan items.",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/plan/deltaNotificationMethod",
"type": "string",
"enum": [
"item/plan/delta"
]
},
"params": {
"$ref": "#/definitions/PlanDeltaNotification"
}
}
},
{
"title": "Command/exec/outputDeltaNotification",
"description": "Stream base64-encoded stdout/stderr chunks for a running `command/exec` session.",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Command/exec/outputDeltaNotificationMethod",
"type": "string",
"enum": [
"command/exec/outputDelta"
]
},
"params": {
"$ref": "#/definitions/CommandExecOutputDeltaNotification"
}
}
},
{
"title": "Process/outputDeltaNotification",
"description": "Stream base64-encoded stdout/stderr chunks for a running `process/spawn` session.",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Process/outputDeltaNotificationMethod",
"type": "string",
"enum": [
"process/outputDelta"
]
},
"params": {
"$ref": "#/definitions/ProcessOutputDeltaNotification"
}
}
},
{
"title": "Process/exitedNotification",
"description": "Final exit notification for a `process/spawn` session.",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Process/exitedNotificationMethod",
"type": "string",
"enum": [
"process/exited"
]
},
"params": {
"$ref": "#/definitions/ProcessExitedNotification"
}
}
},
{
"title": "Item/commandExecution/outputDeltaNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/commandExecution/outputDeltaNotificationMethod",
"type": "string",
"enum": [
"item/commandExecution/outputDelta"
]
},
"params": {
"$ref": "#/definitions/CommandExecutionOutputDeltaNotification"
}
}
},
{
"title": "Item/commandExecution/terminalInteractionNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/commandExecution/terminalInteractionNotificationMethod",
"type": "string",
"enum": [
"item/commandExecution/terminalInteraction"
]
},
"params": {
"$ref": "#/definitions/TerminalInteractionNotification"
}
}
},
{
"title": "Item/fileChange/outputDeltaNotification",
"description": "Deprecated legacy apply_patch output stream notification.",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/fileChange/outputDeltaNotificationMethod",
"type": "string",
"enum": [
"item/fileChange/outputDelta"
]
},
"params": {
"$ref": "#/definitions/FileChangeOutputDeltaNotification"
}
}
},
{
"title": "Item/fileChange/patchUpdatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/fileChange/patchUpdatedNotificationMethod",
"type": "string",
"enum": [
"item/fileChange/patchUpdated"
]
},
"params": {
"$ref": "#/definitions/FileChangePatchUpdatedNotification"
}
}
},
{
"title": "ServerRequest/resolvedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "ServerRequest/resolvedNotificationMethod",
"type": "string",
"enum": [
"serverRequest/resolved"
]
},
"params": {
"$ref": "#/definitions/ServerRequestResolvedNotification"
}
}
},
{
"title": "Item/mcpToolCall/progressNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/mcpToolCall/progressNotificationMethod",
"type": "string",
"enum": [
"item/mcpToolCall/progress"
]
},
"params": {
"$ref": "#/definitions/McpToolCallProgressNotification"
}
}
},
{
"title": "McpServer/oauthLogin/completedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "McpServer/oauthLogin/completedNotificationMethod",
"type": "string",
"enum": [
"mcpServer/oauthLogin/completed"
]
},
"params": {
"$ref": "#/definitions/McpServerOauthLoginCompletedNotification"
}
}
},
{
"title": "McpServer/startupStatus/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "McpServer/startupStatus/updatedNotificationMethod",
"type": "string",
"enum": [
"mcpServer/startupStatus/updated"
]
},
"params": {
"$ref": "#/definitions/McpServerStatusUpdatedNotification"
}
}
},
{
"title": "Account/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Account/updatedNotificationMethod",
"type": "string",
"enum": [
"account/updated"
]
},
"params": {
"$ref": "#/definitions/AccountUpdatedNotification"
}
}
},
{
"title": "Account/rateLimits/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Account/rateLimits/updatedNotificationMethod",
"type": "string",
"enum": [
"account/rateLimits/updated"
]
},
"params": {
"$ref": "#/definitions/AccountRateLimitsUpdatedNotification"
}
}
},
{
"title": "App/list/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "App/list/updatedNotificationMethod",
"type": "string",
"enum": [
"app/list/updated"
]
},
"params": {
"$ref": "#/definitions/AppListUpdatedNotification"
}
}
},
{
"title": "RemoteControl/status/changedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "RemoteControl/status/changedNotificationMethod",
"type": "string",
"enum": [
"remoteControl/status/changed"
]
},
"params": {
"$ref": "#/definitions/RemoteControlStatusChangedNotification"
}
}
},
{
"title": "ExternalAgentConfig/import/progressNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "ExternalAgentConfig/import/progressNotificationMethod",
"type": "string",
"enum": [
"externalAgentConfig/import/progress"
]
},
"params": {
"$ref": "#/definitions/ExternalAgentConfigImportProgressNotification"
}
}
},
{
"title": "ExternalAgentConfig/import/completedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "ExternalAgentConfig/import/completedNotificationMethod",
"type": "string",
"enum": [
"externalAgentConfig/import/completed"
]
},
"params": {
"$ref": "#/definitions/ExternalAgentConfigImportCompletedNotification"
}
}
},
{
"title": "Fs/changedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Fs/changedNotificationMethod",
"type": "string",
"enum": [
"fs/changed"
]
},
"params": {
"$ref": "#/definitions/FsChangedNotification"
}
}
},
{
"title": "Item/reasoning/summaryTextDeltaNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/reasoning/summaryTextDeltaNotificationMethod",
"type": "string",
"enum": [
"item/reasoning/summaryTextDelta"
]
},
"params": {
"$ref": "#/definitions/ReasoningSummaryTextDeltaNotification"
}
}
},
{
"title": "Item/reasoning/summaryPartAddedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/reasoning/summaryPartAddedNotificationMethod",
"type": "string",
"enum": [
"item/reasoning/summaryPartAdded"
]
},
"params": {
"$ref": "#/definitions/ReasoningSummaryPartAddedNotification"
}
}
},
{
"title": "Item/reasoning/textDeltaNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Item/reasoning/textDeltaNotificationMethod",
"type": "string",
"enum": [
"item/reasoning/textDelta"
]
},
"params": {
"$ref": "#/definitions/ReasoningTextDeltaNotification"
}
}
},
{
"title": "Thread/compactedNotification",
"description": "Deprecated: Use `ContextCompaction` item type instead.",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/compactedNotificationMethod",
"type": "string",
"enum": [
"thread/compacted"
]
},
"params": {
"$ref": "#/definitions/ContextCompactedNotification"
}
}
},
{
"title": "Model/reroutedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Model/reroutedNotificationMethod",
"type": "string",
"enum": [
"model/rerouted"
]
},
"params": {
"$ref": "#/definitions/ModelReroutedNotification"
}
}
},
{
"title": "Model/verificationNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Model/verificationNotificationMethod",
"type": "string",
"enum": [
"model/verification"
]
},
"params": {
"$ref": "#/definitions/ModelVerificationNotification"
}
}
},
{
"title": "Turn/moderationMetadataNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Turn/moderationMetadataNotificationMethod",
"type": "string",
"enum": [
"turn/moderationMetadata"
]
},
"params": {
"$ref": "#/definitions/TurnModerationMetadataNotification"
}
}
},
{
"title": "Model/safetyBuffering/updatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Model/safetyBuffering/updatedNotificationMethod",
"type": "string",
"enum": [
"model/safetyBuffering/updated"
]
},
"params": {
"$ref": "#/definitions/ModelSafetyBufferingUpdatedNotification"
}
}
},
{
"title": "WarningNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "WarningNotificationMethod",
"type": "string",
"enum": [
"warning"
]
},
"params": {
"$ref": "#/definitions/WarningNotification"
}
}
},
{
"title": "GuardianWarningNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "GuardianWarningNotificationMethod",
"type": "string",
"enum": [
"guardianWarning"
]
},
"params": {
"$ref": "#/definitions/GuardianWarningNotification"
}
}
},
{
"title": "DeprecationNoticeNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "DeprecationNoticeNotificationMethod",
"type": "string",
"enum": [
"deprecationNotice"
]
},
"params": {
"$ref": "#/definitions/DeprecationNoticeNotification"
}
}
},
{
"title": "ConfigWarningNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "ConfigWarningNotificationMethod",
"type": "string",
"enum": [
"configWarning"
]
},
"params": {
"$ref": "#/definitions/ConfigWarningNotification"
}
}
},
{
"title": "FuzzyFileSearch/sessionUpdatedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "FuzzyFileSearch/sessionUpdatedNotificationMethod",
"type": "string",
"enum": [
"fuzzyFileSearch/sessionUpdated"
]
},
"params": {
"$ref": "#/definitions/FuzzyFileSearchSessionUpdatedNotification"
}
}
},
{
"title": "FuzzyFileSearch/sessionCompletedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "FuzzyFileSearch/sessionCompletedNotificationMethod",
"type": "string",
"enum": [
"fuzzyFileSearch/sessionCompleted"
]
},
"params": {
"$ref": "#/definitions/FuzzyFileSearchSessionCompletedNotification"
}
}
},
{
"title": "Thread/realtime/startedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/startedNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/started"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeStartedNotification"
}
}
},
{
"title": "Thread/realtime/itemAddedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/itemAddedNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/itemAdded"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeItemAddedNotification"
}
}
},
{
"title": "Thread/realtime/transcript/deltaNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/transcript/deltaNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/transcript/delta"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeTranscriptDeltaNotification"
}
}
},
{
"title": "Thread/realtime/transcript/doneNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/transcript/doneNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/transcript/done"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeTranscriptDoneNotification"
}
}
},
{
"title": "Thread/realtime/outputAudio/deltaNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/outputAudio/deltaNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/outputAudio/delta"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeOutputAudioDeltaNotification"
}
}
},
{
"title": "Thread/realtime/sdpNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/sdpNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/sdp"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeSdpNotification"
}
}
},
{
"title": "Thread/realtime/errorNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/errorNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/error"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeErrorNotification"
}
}
},
{
"title": "Thread/realtime/closedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Thread/realtime/closedNotificationMethod",
"type": "string",
"enum": [
"thread/realtime/closed"
]
},
"params": {
"$ref": "#/definitions/ThreadRealtimeClosedNotification"
}
}
},
{
"title": "Windows/worldWritableWarningNotification",
"description": "Notifies the user of world-writable directories on Windows, which cannot be protected by the sandbox.",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Windows/worldWritableWarningNotificationMethod",
"type": "string",
"enum": [
"windows/worldWritableWarning"
]
},
"params": {
"$ref": "#/definitions/WindowsWorldWritableWarningNotification"
}
}
},
{
"title": "WindowsSandbox/setupCompletedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "WindowsSandbox/setupCompletedNotificationMethod",
"type": "string",
"enum": [
"windowsSandbox/setupCompleted"
]
},
"params": {
"$ref": "#/definitions/WindowsSandboxSetupCompletedNotification"
}
}
},
{
"title": "Account/login/completedNotification",
"type": "object",
"required": [
"method",
"params"
],
"properties": {
"method": {
"title": "Account/login/completedNotificationMethod",
"type": "string",
"enum": [
"account/login/completed"
]
},
"params": {
"$ref": "#/definitions/AccountLoginCompletedNotification"
}
}
}
],
"$schema": "http://json-schema.org/draft-07/schema#"
}Variants
Error(ErrorNotification)
ErrorNotification
NEW NOTIFICATIONS
ThreadStarted(ThreadStartedNotification)
Thread/startedNotification
ThreadStatusChanged(ThreadStatusChangedNotification)
Thread/status/changedNotification
ThreadArchived(ThreadArchivedNotification)
Thread/archivedNotification
ThreadDeleted(ThreadDeletedNotification)
Thread/deletedNotification
ThreadUnarchived(ThreadUnarchivedNotification)
Thread/unarchivedNotification
ThreadClosed(ThreadClosedNotification)
Thread/closedNotification
SkillsChanged(SkillsChangedNotification)
Skills/changedNotification
ThreadNameUpdated(ThreadNameUpdatedNotification)
Thread/name/updatedNotification
ThreadGoalUpdated(ThreadGoalUpdatedNotification)
Thread/goal/updatedNotification
ThreadGoalCleared(ThreadGoalClearedNotification)
Thread/goal/clearedNotification
ThreadSettingsUpdated(ThreadSettingsUpdatedNotification)
Thread/settings/updatedNotification
ThreadTokenUsageUpdated(ThreadTokenUsageUpdatedNotification)
Thread/tokenUsage/updatedNotification
TurnStarted(TurnStartedNotification)
Turn/startedNotification
HookStarted(HookStartedNotification)
Hook/startedNotification
TurnCompleted(TurnCompletedNotification)
Turn/completedNotification
HookCompleted(HookCompletedNotification)
Hook/completedNotification
TurnDiffUpdated(TurnDiffUpdatedNotification)
Turn/diff/updatedNotification
TurnPlanUpdated(TurnPlanUpdatedNotification)
Turn/plan/updatedNotification
ItemStarted(ItemStartedNotification)
Item/startedNotification
ItemAutoApprovalReviewStarted(ItemGuardianApprovalReviewStartedNotification)
Item/autoApprovalReview/startedNotification
ItemAutoApprovalReviewCompleted(ItemGuardianApprovalReviewCompletedNotification)
Item/autoApprovalReview/completedNotification
ItemCompleted(ItemCompletedNotification)
Item/completedNotification
ItemAgentMessageDelta(AgentMessageDeltaNotification)
Item/agentMessage/deltaNotification
ItemPlanDelta(PlanDeltaNotification)
Item/plan/deltaNotification
EXPERIMENTAL - proposed plan streaming deltas for plan items.
CommandExecOutputDelta(CommandExecOutputDeltaNotification)
Command/exec/outputDeltaNotification
Stream base64-encoded stdout/stderr chunks for a running command/exec session.
ProcessOutputDelta(ProcessOutputDeltaNotification)
Process/outputDeltaNotification
Stream base64-encoded stdout/stderr chunks for a running process/spawn session.
ProcessExited(ProcessExitedNotification)
Process/exitedNotification
Final exit notification for a process/spawn session.
ItemCommandExecutionOutputDelta(CommandExecutionOutputDeltaNotification)
Item/commandExecution/outputDeltaNotification
ItemCommandExecutionTerminalInteraction(TerminalInteractionNotification)
Item/commandExecution/terminalInteractionNotification
ItemFileChangeOutputDelta(FileChangeOutputDeltaNotification)
Item/fileChange/outputDeltaNotification
Deprecated legacy apply_patch output stream notification.
ItemFileChangePatchUpdated(FileChangePatchUpdatedNotification)
Item/fileChange/patchUpdatedNotification
ServerRequestResolved(ServerRequestResolvedNotification)
ServerRequest/resolvedNotification
ItemMcpToolCallProgress(McpToolCallProgressNotification)
Item/mcpToolCall/progressNotification
McpServerOauthLoginCompleted(McpServerOauthLoginCompletedNotification)
McpServer/oauthLogin/completedNotification
McpServerStartupStatusUpdated(McpServerStatusUpdatedNotification)
McpServer/startupStatus/updatedNotification
AccountUpdated(AccountUpdatedNotification)
Account/updatedNotification
AccountRateLimitsUpdated(AccountRateLimitsUpdatedNotification)
Account/rateLimits/updatedNotification
AppListUpdated(AppListUpdatedNotification)
App/list/updatedNotification
RemoteControlStatusChanged(RemoteControlStatusChangedNotification)
RemoteControl/status/changedNotification
ExternalAgentConfigImportProgress(ExternalAgentConfigImportProgressNotification)
ExternalAgentConfig/import/progressNotification
ExternalAgentConfigImportCompleted(ExternalAgentConfigImportCompletedNotification)
ExternalAgentConfig/import/completedNotification
FsChanged(FsChangedNotification)
Fs/changedNotification
ItemReasoningSummaryTextDelta(ReasoningSummaryTextDeltaNotification)
Item/reasoning/summaryTextDeltaNotification
ItemReasoningSummaryPartAdded(ReasoningSummaryPartAddedNotification)
Item/reasoning/summaryPartAddedNotification
ItemReasoningTextDelta(ReasoningTextDeltaNotification)
Item/reasoning/textDeltaNotification
ThreadCompacted(ContextCompactedNotification)
Thread/compactedNotification
Deprecated: Use ContextCompaction item type instead.
ModelRerouted(ModelReroutedNotification)
Model/reroutedNotification
ModelVerification(ModelVerificationNotification)
Model/verificationNotification
TurnModerationMetadata(TurnModerationMetadataNotification)
Turn/moderationMetadataNotification
ModelSafetyBufferingUpdated(ModelSafetyBufferingUpdatedNotification)
Model/safetyBuffering/updatedNotification
Warning(WarningNotification)
WarningNotification
GuardianWarning(GuardianWarningNotification)
GuardianWarningNotification
DeprecationNotice(DeprecationNoticeNotification)
DeprecationNoticeNotification
ConfigWarning(ConfigWarningNotification)
ConfigWarningNotification
FuzzyFileSearchSessionUpdated(FuzzyFileSearchSessionUpdatedNotification)
FuzzyFileSearch/sessionUpdatedNotification
FuzzyFileSearchSessionCompleted(FuzzyFileSearchSessionCompletedNotification)
FuzzyFileSearch/sessionCompletedNotification
ThreadRealtimeStarted(ThreadRealtimeStartedNotification)
Thread/realtime/startedNotification
ThreadRealtimeItemAdded(ThreadRealtimeItemAddedNotification)
Thread/realtime/itemAddedNotification
ThreadRealtimeTranscriptDelta(ThreadRealtimeTranscriptDeltaNotification)
Thread/realtime/transcript/deltaNotification
ThreadRealtimeTranscriptDone(ThreadRealtimeTranscriptDoneNotification)
Thread/realtime/transcript/doneNotification
ThreadRealtimeOutputAudioDelta(ThreadRealtimeOutputAudioDeltaNotification)
Thread/realtime/outputAudio/deltaNotification
ThreadRealtimeSdp(ThreadRealtimeSdpNotification)
Thread/realtime/sdpNotification
ThreadRealtimeError(ThreadRealtimeErrorNotification)
Thread/realtime/errorNotification
ThreadRealtimeClosed(ThreadRealtimeClosedNotification)
Thread/realtime/closedNotification
WindowsWorldWritableWarning(WindowsWorldWritableWarningNotification)
Windows/worldWritableWarningNotification
Notifies the user of world-writable directories on Windows, which cannot be protected by the sandbox.
WindowsSandboxSetupCompleted(WindowsSandboxSetupCompletedNotification)
WindowsSandbox/setupCompletedNotification
AccountLoginCompleted(AccountLoginCompletedNotification)
Account/login/completedNotification
Implementations
Sourceimpl ServerNotification
impl ServerNotification
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
The wire method name, e.g. "turn/completed". Useful for logging a
non-sensitive identifier without the full (potentially large or
sensitive) notification payload.