pub struct ItemGuardianApprovalReviewCompletedNotification {
pub action: GuardianApprovalReviewAction,
pub completed_at_ms: i64,
pub decision_source: AutoReviewDecisionSource,
pub review: GuardianApprovalReview,
pub review_id: String,
pub started_at_ms: i64,
pub target_item_id: Option<String>,
pub thread_id: String,
pub turn_id: String,
}Expand description
[UNSTABLE] Temporary notification payload for approval auto-review. This shape is expected to change soon.
JSON schema
{
"title": "ItemGuardianApprovalReviewCompletedNotification",
"description": "[UNSTABLE] Temporary notification payload for approval auto-review. This shape is expected to change soon.",
"type": "object",
"required": [
"action",
"completedAtMs",
"decisionSource",
"review",
"reviewId",
"startedAtMs",
"threadId",
"turnId"
],
"properties": {
"action": {
"$ref": "#/definitions/GuardianApprovalReviewAction"
},
"completedAtMs": {
"description": "Unix timestamp (in milliseconds) when this review completed.",
"type": "integer",
"format": "int64"
},
"decisionSource": {
"$ref": "#/definitions/AutoReviewDecisionSource"
},
"review": {
"$ref": "#/definitions/GuardianApprovalReview"
},
"reviewId": {
"description": "Stable identifier for this review.",
"type": "string"
},
"startedAtMs": {
"description": "Unix timestamp (in milliseconds) when this review started.",
"type": "integer",
"format": "int64"
},
"targetItemId": {
"description": "Identifier for the reviewed item or tool call when one exists.\n\nIn most cases, one review maps to one target item. The exceptions are - execve reviews, where a single command may contain multiple execve calls to review (only possible when using the shell_zsh_fork feature) - network policy reviews, where there is no target item\n\nA network call is triggered by a CommandExecution item, so having a target_item_id set to the CommandExecution item would be misleading because the review is about the network call, not the command execution. Therefore, target_item_id is set to None for network policy reviews.",
"type": [
"string",
"null"
]
},
"threadId": {
"type": "string"
},
"turnId": {
"type": "string"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
action: GuardianApprovalReviewActioncompleted_at_ms: i64Unix timestamp (in milliseconds) when this review completed.
decision_source: AutoReviewDecisionSourcereview: GuardianApprovalReviewreview_id: StringStable identifier for this review.
started_at_ms: i64Unix timestamp (in milliseconds) when this review started.
target_item_id: Option<String>Identifier for the reviewed item or tool call when one exists.
In most cases, one review maps to one target item. The exceptions are - execve reviews, where a single command may contain multiple execve calls to review (only possible when using the shell_zsh_fork feature) - network policy reviews, where there is no target item
A network call is triggered by a CommandExecution item, so having a target_item_id set to the CommandExecution item would be misleading because the review is about the network call, not the command execution. Therefore, target_item_id is set to None for network policy reviews.
thread_id: Stringturn_id: StringTrait Implementations
Sourceimpl Clone for ItemGuardianApprovalReviewCompletedNotification
impl Clone for ItemGuardianApprovalReviewCompletedNotification
Sourcefn clone(&self) -> ItemGuardianApprovalReviewCompletedNotification
fn clone(&self) -> ItemGuardianApprovalReviewCompletedNotification
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more