pub struct PluginMarketplaceEntry {
pub interface: Option<MarketplaceInterface>,
pub name: String,
pub path: Option<AbsolutePathBuf>,
pub plugins: Vec<PluginSummary>,
}Expand description
PluginMarketplaceEntry
JSON schema
{
"type": "object",
"required": [
"name",
"plugins"
],
"properties": {
"interface": {
"anyOf": [
{
"$ref": "#/definitions/MarketplaceInterface"
},
{
"type": "null"
}
]
},
"name": {
"type": "string"
},
"path": {
"description": "Local marketplace file path when the marketplace is backed by a local file. Remote-only catalog marketplaces do not have a local path.",
"anyOf": [
{
"$ref": "#/definitions/AbsolutePathBuf"
},
{
"type": "null"
}
]
},
"plugins": {
"type": "array",
"items": {
"$ref": "#/definitions/PluginSummary"
}
}
}
}Fields
interface: Option<MarketplaceInterface>name: Stringpath: Option<AbsolutePathBuf>Local marketplace file path when the marketplace is backed by a local file. Remote-only catalog marketplaces do not have a local path.
plugins: Vec<PluginSummary>Trait Implementations
Sourceimpl Clone for PluginMarketplaceEntry
impl Clone for PluginMarketplaceEntry
Sourcefn clone(&self) -> PluginMarketplaceEntry
fn clone(&self) -> PluginMarketplaceEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PluginMarketplaceEntry
impl Debug for PluginMarketplaceEntry
Sourceimpl<'de> Deserialize<'de> for PluginMarketplaceEntry
impl<'de> Deserialize<'de> for PluginMarketplaceEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more