pub struct ThreadSettingsUpdateParams {Show 13 fields
pub approval_policy: Option<AskForApproval>,
pub approvals_reviewer: Option<ApprovalsReviewer>,
pub collaboration_mode: Option<CollaborationMode>,
pub cwd: Option<String>,
pub effort: Option<ReasoningEffort>,
pub model: Option<String>,
pub multi_agent_mode: Option<MultiAgentMode>,
pub permissions: Option<String>,
pub personality: Option<Personality>,
pub sandbox_policy: Option<SandboxPolicy>,
pub service_tier: Option<String>,
pub summary: Option<ReasoningSummary>,
pub thread_id: String,
}Expand description
ThreadSettingsUpdateParams
JSON schema
{
"title": "ThreadSettingsUpdateParams",
"type": "object",
"required": [
"threadId"
],
"properties": {
"approvalPolicy": {
"description": "Override the approval policy for subsequent turns.",
"anyOf": [
{
"$ref": "#/definitions/AskForApproval"
},
{
"type": "null"
}
]
},
"approvalsReviewer": {
"description": "Override where approval requests are routed for subsequent turns.",
"anyOf": [
{
"$ref": "#/definitions/ApprovalsReviewer"
},
{
"type": "null"
}
]
},
"collaborationMode": {
"description": "EXPERIMENTAL - Set a pre-set collaboration mode for subsequent turns.\n\nFor `collaboration_mode.settings.developer_instructions`, `null` means \"use the built-in instructions for the selected mode\".",
"anyOf": [
{
"$ref": "#/definitions/CollaborationMode"
},
{
"type": "null"
}
]
},
"cwd": {
"description": "Override the working directory for subsequent turns.",
"type": [
"string",
"null"
]
},
"effort": {
"description": "Override the reasoning effort for subsequent turns.",
"anyOf": [
{
"$ref": "#/definitions/ReasoningEffort"
},
{
"type": "null"
}
]
},
"model": {
"description": "Override the model for subsequent turns.",
"type": [
"string",
"null"
]
},
"multiAgentMode": {
"description": "@deprecated Ignored. Use `effort: \"ultra\"` for proactive multi-agent behavior.",
"anyOf": [
{
"$ref": "#/definitions/MultiAgentMode"
},
{
"type": "null"
}
]
},
"permissions": {
"description": "Select a named permissions profile id for subsequent turns. Cannot be combined with `sandboxPolicy`.",
"type": [
"string",
"null"
]
},
"personality": {
"description": "Override the personality for subsequent turns.",
"anyOf": [
{
"$ref": "#/definitions/Personality"
},
{
"type": "null"
}
]
},
"sandboxPolicy": {
"description": "Override the sandbox policy for subsequent turns.",
"anyOf": [
{
"$ref": "#/definitions/SandboxPolicy"
},
{
"type": "null"
}
]
},
"serviceTier": {
"description": "Override the service tier for subsequent turns. `null` clears the current service tier; omission leaves it unchanged.",
"type": [
"string",
"null"
]
},
"summary": {
"description": "Override the reasoning summary for subsequent turns.",
"anyOf": [
{
"$ref": "#/definitions/ReasoningSummary"
},
{
"type": "null"
}
]
},
"threadId": {
"type": "string"
}
},
"$schema": "http://json-schema.org/draft-07/schema#"
}Fields
approval_policy: Option<AskForApproval>Override the approval policy for subsequent turns.
approvals_reviewer: Option<ApprovalsReviewer>Override where approval requests are routed for subsequent turns.
collaboration_mode: Option<CollaborationMode>EXPERIMENTAL - Set a pre-set collaboration mode for subsequent turns.
For collaboration_mode.settings.developer_instructions, null means “use the built-in instructions for the selected mode”.
cwd: Option<String>Override the working directory for subsequent turns.
effort: Option<ReasoningEffort>Override the reasoning effort for subsequent turns.
model: Option<String>Override the model for subsequent turns.
multi_agent_mode: Option<MultiAgentMode>@deprecated Ignored. Use effort: "ultra" for proactive multi-agent behavior.
permissions: Option<String>Select a named permissions profile id for subsequent turns. Cannot be combined with sandboxPolicy.
personality: Option<Personality>Override the personality for subsequent turns.
sandbox_policy: Option<SandboxPolicy>Override the sandbox policy for subsequent turns.
service_tier: Option<String>Override the service tier for subsequent turns. null clears the current service tier; omission leaves it unchanged.
summary: Option<ReasoningSummary>Override the reasoning summary for subsequent turns.
thread_id: StringTrait Implementations
Sourceimpl Clone for ThreadSettingsUpdateParams
impl Clone for ThreadSettingsUpdateParams
Sourcefn clone(&self) -> ThreadSettingsUpdateParams
fn clone(&self) -> ThreadSettingsUpdateParams
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more